@@ -11,7 +11,7 @@ from wagtail.admin.userbar import (
     ExplorePageItem,
     RejectModerationEditPageItem,
 )
-from wagtail.models import PAGE_TEMPLATE_VAR, Page, PageRevision
+from wagtail.models import PAGE_TEMPLATE_VAR, Page, Revision
 from wagtail.users.models import UserProfile
 
 register = template.Library()
@@ -48,6 +48,10 @@ def wagtailuserbar(context, position="bottom-right"):
     if not user.has_perm("wagtailadmin.access_admin"):
         return ""
 
+    # Don't render if page is loaded in page editor's preview panel iframe
+    if getattr(request, "in_preview_panel", False):
+        return ""
+
     # Render the userbar using the user's preferred admin language
     userprofile = UserProfile.get_for_user(user)
     with translation.override(userprofile.get_preferred_language()):
@@ -62,13 +66,17 @@ def wagtailuserbar(context, position="bottom-right"):
             if revision_id:
                 items = [
                     AdminItem(),
-                    ExplorePageItem(PageRevision.objects.get(id=revision_id).page),
-                    EditPageItem(PageRevision.objects.get(id=revision_id).page),
+                    ExplorePageItem(
+                        Revision.page_revisions.get(id=revision_id).content_object
+                    ),
+                    EditPageItem(
+                        Revision.page_revisions.get(id=revision_id).content_object
+                    ),
                     ApproveModerationEditPageItem(
-                        PageRevision.objects.get(id=revision_id)
+                        Revision.page_revisions.get(id=revision_id)
                     ),
                     RejectModerationEditPageItem(
-                        PageRevision.objects.get(id=revision_id)
+                        Revision.page_revisions.get(id=revision_id)
                     ),
                 ]
             else:
