@@ -11,7 +11,7 @@ from django.utils import timezone
 from django.utils.translation import gettext_lazy as _
 
 from wagtail.admin.tests.pages.timestamps import submittable_timestamp
-from wagtail.models import GroupPagePermission, Locale, Page, PageRevision
+from wagtail.models import GroupPagePermission, Locale, Page, Revision
 from wagtail.signals import page_published
 from wagtail.test.testapp.models import (
     BusinessChild,
@@ -19,7 +19,9 @@ from wagtail.test.testapp.models import (
     BusinessSubIndex,
     DefaultStreamPage,
     PersonPage,
+    SimpleChildPage,
     SimplePage,
+    SimpleParentPage,
     SingletonPage,
     SingletonPageViaMaxCount,
     StandardChild,
@@ -73,6 +75,30 @@ class TestPageCreation(TestCase, WagtailTestUtils):
         # List should not contain page types not in the subpage_types list
         self.assertNotContains(response, "Simple page")
 
+    def test_no_subpage_type_available_to_create(self):
+        # Test if all subpages have reached their max_count_per_parent limit
+        simple_parent_page = SimpleParentPage(
+            title="Hello World!",
+            slug="hello-world",
+        )
+        self.root_page.add_child(instance=simple_parent_page)
+        simple_child_page = SimpleChildPage(
+            title="Hello World!",
+            slug="hello-world",
+        )
+        simple_parent_page.add_child(instance=simple_child_page)
+        response = self.client.get(
+            reverse("wagtailadmin_pages:add_subpage", args=(simple_parent_page.id,))
+        )
+        self.assertEqual(response.status_code, 200)
+        # if there is no page_type available then this message should be shown.
+        self.assertContains(
+            response, "Sorry, you cannot create a page at this location."
+        )
+        self.assertNotContains(
+            response, "Choose which type of page you'd like to create."
+        )
+
     def test_add_subpage_with_one_valid_subpage_type(self):
         # Add a BusinessSubIndex to test business rules in
         business_index = BusinessIndex(
@@ -458,7 +484,7 @@ class TestPageCreation(TestCase, WagtailTestUtils):
 
         # No revisions with approved_go_live_at
         self.assertFalse(
-            PageRevision.objects.filter(page=page)
+            Revision.page_revisions.filter(object_id=page.id)
             .exclude(approved_go_live_at__isnull=True)
             .exists()
         )
@@ -610,7 +636,7 @@ class TestPageCreation(TestCase, WagtailTestUtils):
 
         # A revision with approved_go_live_at should exist now
         self.assertTrue(
-            PageRevision.objects.filter(page=page)
+            Revision.page_revisions.filter(object_id=page.id)
             .exclude(approved_go_live_at__isnull=True)
             .exists()
         )
@@ -722,7 +748,10 @@ class TestPageCreation(TestCase, WagtailTestUtils):
 
         # Check the JSON response
         self.assertEqual(response.status_code, 200)
-        self.assertJSONEqual(response.content.decode(), {"is_valid": True})
+        self.assertJSONEqual(
+            response.content.decode(),
+            {"is_valid": True, "is_available": True},
+        )
 
         response = self.client.get(preview_url)
 
