@@ -425,7 +425,7 @@ class TestTabbedInterface(TestCase, WagtailTestUtils):
 
         # result should contain tab buttons
         self.assertIn(
-            '<a id="tab-label-event-details" href="#tab-event-details" class="w-tabs__tab shiny" role="tab" aria-selected="false" tabindex="-1">',
+            '<a id="tab-label-event_details" href="#tab-event_details" class="w-tabs__tab shiny" role="tab" aria-selected="false" tabindex="-1">',
             result,
         )
         self.assertIn(
@@ -434,7 +434,7 @@ class TestTabbedInterface(TestCase, WagtailTestUtils):
         )
 
         # result should contain tab panels
-        self.assertIn('aria-labelledby="tab-label-event-details"', result)
+        self.assertIn('aria-labelledby="tab-label-event_details"', result)
         self.assertIn('aria-labelledby="tab-label-speakers"', result)
 
         # result should contain rendered content from descendants
@@ -484,7 +484,7 @@ class TestTabbedInterface(TestCase, WagtailTestUtils):
         )
         result = tabbed_interface.render_html()
         self.assertIn(
-            '<a id="tab-label-event-details" href="#tab-event-details" class="w-tabs__tab shiny" role="tab" aria-selected="false" tabindex="-1">',
+            '<a id="tab-label-event_details" href="#tab-event_details" class="w-tabs__tab shiny" role="tab" aria-selected="false" tabindex="-1">',
             result,
         )
         self.assertIn(
@@ -506,7 +506,7 @@ class TestTabbedInterface(TestCase, WagtailTestUtils):
         )
         result = tabbed_interface.render_html()
         self.assertIn(
-            '<a id="tab-label-event-details" href="#tab-event-details" class="w-tabs__tab shiny" role="tab" aria-selected="false" tabindex="-1">',
+            '<a id="tab-label-event_details" href="#tab-event_details" class="w-tabs__tab shiny" role="tab" aria-selected="false" tabindex="-1">',
             result,
         )
         self.assertIn(
@@ -560,14 +560,17 @@ class TestObjectList(TestCase):
         result = object_list.render_html()
 
         # result should contain ObjectList furniture
-        self.assertIn('<ul class="objects">', result)
+        self.assertIn('<div class="w-panel__header">', result)
 
         # result should contain labels for children
-        self.assertInHTML('<label for="id_date_from">Start date</label>', result)
+        self.assertIn(
+            '<label for="id_date_from" id="id_date_from-label">',
+            result,
+        )
 
         # result should include help text for children
         self.assertInHTML(
-            '<div class="object-help help"> <svg class="icon icon-help default" aria-hidden="true"><use href="#icon-help"></use></svg> Not required if event is on a single day</div>',
+            '<div class="help">Not required if event is on a single day</div>',
             result,
         )
 
@@ -632,7 +635,7 @@ class TestFieldPanel(TestCase):
             end_date_panel_with_overridden_heading.bound_field.label, "New heading"
         )
 
-    def test_render_as_object(self):
+    def test_render_html(self):
         form = self.EventPageForm(
             {
                 "title": "Pontypridd sheepdog trials",
@@ -649,53 +652,15 @@ class TestFieldPanel(TestCase):
             form=form,
             request=self.request,
         )
-        result = field_panel.render_as_object()
+        result = field_panel.render_html()
 
-        # check that label appears as a legend in the 'object' wrapper,
-        # but not as a field label (that would be provided by ObjectList instead)
-        self.assertIn("<legend>End date</legend>", result)
-        self.assertNotIn('<label for="id_date_to">End date:</label>', result)
-
-        # check that help text is not included (it's provided by ObjectList instead)
-        self.assertNotIn("Not required if event is on a single day", result)
-
-        # check that the populated form field is included
-        self.assertIn('value="2014-07-22"', result)
-
-        # there should be no errors on this field
-        self.assertNotIn('<p class="error-message">', result)
-
-    def test_render_as_field(self):
-        form = self.EventPageForm(
-            {
-                "title": "Pontypridd sheepdog trials",
-                "date_from": "2014-07-20",
-                "date_to": "2014-07-22",
-            },
-            instance=self.event,
-        )
-
-        form.is_valid()
-
-        field_panel = self.end_date_panel.get_bound_panel(
-            instance=self.event,
-            form=form,
-            request=self.request,
-        )
-        result = field_panel.render_as_field()
-
-        # check that label is output in the 'field' style
-        self.assertIn('<label for="id_date_to">End date:</label>', result)
-        self.assertNotIn("<legend>End date</legend>", result)
-
-        # check that help text is included
         self.assertIn("Not required if event is on a single day", result)
 
         # check that the populated form field is included
         self.assertIn('value="2014-07-22"', result)
 
         # there should be no errors on this field
-        self.assertNotIn('<p class="error-message">', result)
+        self.assertNotIn("error-message", result)
 
     def test_required_fields(self):
         result = self.end_date_panel.get_form_options()["fields"]
@@ -718,10 +683,9 @@ class TestFieldPanel(TestCase):
             form=form,
             request=self.request,
         )
-        result = field_panel.render_as_field()
+        result = field_panel.render_html()
 
-        self.assertIn('<p class="error-message">', result)
-        self.assertIn("<span>Enter a valid date.</span>", result)
+        self.assertIn("Enter a valid date.", result)
 
     def test_repr(self):
         form = self.EventPageForm()
@@ -763,10 +727,11 @@ class TestFieldRowPanel(TestCase):
             [
                 FieldPanel("date_from", classname="col4", heading="Start"),
                 FieldPanel("date_to", classname="coltwo"),
-            ]
+            ],
+            help_text="Confirmed event dates only",
         ).bind_to_model(EventPage)
 
-    def test_render_as_object(self):
+    def test_render_html(self):
         form = self.EventPageForm(
             {
                 "title": "Pontypridd sheepdog trials",
@@ -783,48 +748,25 @@ class TestFieldRowPanel(TestCase):
             form=form,
             request=self.request,
         )
-        result = field_panel.render_as_object()
-
-        # check that the populated form field is included
-        self.assertIn('value="2014-07-22"', result)
-
-        # there should be no errors on this field
-        self.assertNotIn('<p class="error-message">', result)
-
-    def test_render_as_field(self):
-        form = self.EventPageForm(
-            {
-                "title": "Pontypridd sheepdog trials",
-                "date_from": "2014-07-20",
-                "date_to": "2014-07-22",
-            },
-            instance=self.event,
-        )
-
-        form.is_valid()
-
-        field_panel = self.dates_panel.get_bound_panel(
-            instance=self.event,
-            form=form,
-            request=self.request,
-        )
-        result = field_panel.render_as_field()
+        result = field_panel.render_html()
 
         # check that label is output in the 'field' style
-        self.assertIn('<label for="id_date_to">End date:</label>', result)
-        self.assertNotIn("<legend>End date</legend>", result)
+        self.assertIn(
+            '<label class="w-field__label" for="id_date_to" id="id_date_to-label">',
+            result,
+        )
 
-        # check that label is overridden with the 'heading' argument
-        self.assertIn('<label for="id_date_from">Start:</label>', result)
-
-        # check that help text is included
+        # check that field help text is included
         self.assertIn("Not required if event is on a single day", result)
 
+        # check that row help text is included
+        self.assertIn("Confirmed event dates only", result)
+
         # check that the populated form field is included
         self.assertIn('value="2014-07-22"', result)
 
         # there should be no errors on this field
-        self.assertNotIn('<p class="error-message">', result)
+        self.assertNotIn("error-message", result)
 
     def test_error_message_is_rendered(self):
         form = self.EventPageForm(
@@ -843,54 +785,9 @@ class TestFieldRowPanel(TestCase):
             form=form,
             request=self.request,
         )
-        result = field_panel.render_as_field()
+        result = field_panel.render_html()
 
-        self.assertIn('<p class="error-message">', result)
-        self.assertIn("<span>Enter a valid date.</span>", result)
-
-    def test_add_col_when_wrong_in_panel_def(self):
-        form = self.EventPageForm(
-            {
-                "title": "Pontypridd sheepdog trials",
-                "date_from": "2014-07-20",
-                "date_to": "2014-07-33",
-            },
-            instance=self.event,
-        )
-
-        form.is_valid()
-
-        field_panel = self.dates_panel.get_bound_panel(
-            instance=self.event,
-            form=form,
-            request=self.request,
-        )
-
-        result = field_panel.render_as_field()
-
-        self.assertIn('<li class="field-col coltwo error date_field col6">', result)
-
-    def test_added_col_doesnt_change_siblings(self):
-        form = self.EventPageForm(
-            {
-                "title": "Pontypridd sheepdog trials",
-                "date_from": "2014-07-20",
-                "date_to": "2014-07-33",
-            },
-            instance=self.event,
-        )
-
-        form.is_valid()
-
-        field_panel = self.dates_panel.get_bound_panel(
-            instance=self.event,
-            form=form,
-            request=self.request,
-        )
-
-        result = field_panel.render_as_field()
-
-        self.assertIn('<li class="field-col col4', result)
+        self.assertIn("Enter a valid date.", result)
 
 
 class TestFieldRowPanelWithChooser(TestCase):
@@ -918,7 +815,7 @@ class TestFieldRowPanelWithChooser(TestCase):
             ]
         ).bind_to_model(EventPage)
 
-    def test_render_as_object(self):
+    def test_render_html(self):
         form = self.EventPageForm(
             {
                 "title": "Pontypridd sheepdog trials",
@@ -935,13 +832,13 @@ class TestFieldRowPanelWithChooser(TestCase):
             form=form,
             request=self.request,
         )
-        result = field_panel.render_as_object()
+        result = field_panel.render_html()
 
         # check that the populated form field is included
         self.assertIn('value="2014-07-20"', result)
 
         # there should be no errors on this field
-        self.assertNotIn('<p class="error-message">', result)
+        self.assertNotIn("error-message", result)
 
 
 class TestPageChooserPanel(TestCase):
@@ -977,8 +874,8 @@ class TestPageChooserPanel(TestCase):
         self.assertEqual(type(self.form.fields["page"].widget), AdminPageChooser)
 
     def test_render_js_init(self):
-        result = self.page_chooser_panel.render_as_field()
-        expected_js = 'createPageChooser("{id}", {parent}, {{"model_names": ["{model}"], "can_choose_root": false, "user_perms": null}});'.format(
+        result = self.page_chooser_panel.render_html()
+        expected_js = 'new PageChooser("{id}", {parent}, {{"model_names": ["{model}"], "can_choose_root": false, "user_perms": null}});'.format(
             id="id_page", model="wagtailcore.page", parent=self.events_index_page.id
         )
 
@@ -997,21 +894,24 @@ class TestPageChooserPanel(TestCase):
         page_chooser_panel = my_page_chooser_panel.get_bound_panel(
             instance=self.test_instance, form=form, request=self.request
         )
-        result = page_chooser_panel.render_as_field()
+        result = page_chooser_panel.render_html()
 
-        # the canChooseRoot flag on createPageChooser should now be true
-        expected_js = 'createPageChooser("{id}", {parent}, {{"model_names": ["{model}"], "can_choose_root": true, "user_perms": null}});'.format(
+        # the canChooseRoot flag on PageChooser should now be true
+        expected_js = 'new PageChooser("{id}", {parent}, {{"model_names": ["{model}"], "can_choose_root": true, "user_perms": null}});'.format(
             id="id_page", model="wagtailcore.page", parent=self.events_index_page.id
         )
         self.assertIn(expected_js, result)
 
-    def test_render_as_field(self):
-        result = self.page_chooser_panel.render_as_field()
-        self.assertIn('<p class="help">help text</p>', result)
-        self.assertIn('<span class="title">Christmas</span>', result)
+    def test_render_html(self):
+        result = self.page_chooser_panel.render_html()
+        self.assertIn('<div class="help">help text</div>', result)
         self.assertIn(
-            '<a href="/admin/pages/%d/edit/" class="edit-link button button-small button-secondary" target="_blank" rel="noreferrer">'
-            "Edit this page</a>" % self.christmas_page.id,
+            '<div class="chooser__title" data-chooser-title id="id_page-title">Christmas</div>',
+            result,
+        )
+        self.assertIn(
+            '<a href="/admin/pages/%d/edit/" aria-describedby="id_page-title" class="edit-link button button-small button-secondary" target="_blank" rel="noreferrer">Edit this page</a>'
+            % self.christmas_page.id,
             result,
         )
 
@@ -1021,10 +921,13 @@ class TestPageChooserPanel(TestCase):
         page_chooser_panel = self.my_page_chooser_panel.get_bound_panel(
             instance=test_instance, form=form, request=self.request
         )
-        result = page_chooser_panel.render_as_field()
+        result = page_chooser_panel.render_html()
 
-        self.assertIn('<p class="help">help text</p>', result)
-        self.assertIn('<span class="title"></span>', result)
+        self.assertIn('<div class="help">help text</div>', result)
+        self.assertIn(
+            '<div class="chooser__title" data-chooser-title id="id_page-title"></div>',
+            result,
+        )
         self.assertIn("Choose a page", result)
 
     def test_render_error(self):
@@ -1034,9 +937,7 @@ class TestPageChooserPanel(TestCase):
         page_chooser_panel = self.my_page_chooser_panel.get_bound_panel(
             instance=self.test_instance, form=form, request=self.request
         )
-        self.assertIn(
-            "<span>This field is required.</span>", page_chooser_panel.render_as_field()
-        )
+        self.assertIn("error-message", page_chooser_panel.render_html())
 
     def test_override_page_type(self):
         # Model has a foreign key to Page, but we specify EventPage in the PageChooserPanel
@@ -1051,8 +952,8 @@ class TestPageChooserPanel(TestCase):
             instance=self.test_instance, form=form, request=self.request
         )
 
-        result = page_chooser_panel.render_as_field()
-        expected_js = 'createPageChooser("{id}", {parent}, {{"model_names": ["{model}"], "can_choose_root": false, "user_perms": null}});'.format(
+        result = page_chooser_panel.render_html()
+        expected_js = 'new PageChooser("{id}", {parent}, {{"model_names": ["{model}"], "can_choose_root": false, "user_perms": null}});'.format(
             id="id_page", model="tests.eventpage", parent=self.events_index_page.id
         )
 
@@ -1071,8 +972,8 @@ class TestPageChooserPanel(TestCase):
             instance=self.test_instance, form=form, request=self.request
         )
 
-        result = page_chooser_panel.render_as_field()
-        expected_js = 'createPageChooser("{id}", {parent}, {{"model_names": ["{model}"], "can_choose_root": false, "user_perms": null}});'.format(
+        result = page_chooser_panel.render_html()
+        expected_js = 'new PageChooser("{id}", {parent}, {{"model_names": ["{model}"], "can_choose_root": false, "user_perms": null}});'.format(
             id="id_page", model="tests.eventpage", parent=self.events_index_page.id
         )
 
@@ -1128,13 +1029,23 @@ class TestInlinePanel(TestCase, WagtailTestUtils):
             instance=event_page, form=form, request=self.request
         )
 
-        result = panel.render_as_field()
+        result = panel.render_html()
 
-        self.assertIn('<li class="object classname-for-speakers">', result)
-        self.assertIn('<label for="id_speakers-0-first_name">Name:</label>', result)
+        # FIXME: reinstate when we pass classnames to the template again
+        # self.assertIn('<li class="object classname-for-speakers">', result)
+        self.assertIn(
+            '<label class="w-field__label" for="id_speakers-0-first_name" id="id_speakers-0-first_name-label">',
+            result,
+        )
         self.assertIn('value="Father"', result)
-        self.assertIn('<label for="id_speakers-0-last_name">Surname:</label>', result)
-        self.assertIn('<label for="id_speakers-0-image">Image:</label>', result)
+        self.assertIn(
+            '<label class="w-field__label" for="id_speakers-0-last_name" id="id_speakers-0-last_name-label">',
+            result,
+        )
+        self.assertIn(
+            '<label class="w-field__label" for="id_speakers-0-image" id="id_speakers-0-image-label">',
+            result,
+        )
         self.assertIn("Choose an image", result)
 
         # rendered panel must also contain hidden fields for id, DELETE and ORDER
@@ -1194,13 +1105,17 @@ class TestInlinePanel(TestCase, WagtailTestUtils):
             instance=event_page, form=form, request=self.request
         )
 
-        result = panel.render_as_field()
+        result = panel.render_html()
 
         # rendered panel should contain first_name rendered as a text area, but no last_name field
-        self.assertIn('<label for="id_speakers-0-first_name">Name:</label>', result)
+        self.assertIn(
+            '<label class="w-field__label" for="id_speakers-0-first_name" id="id_speakers-0-first_name-label">',
+            result,
+        )
         self.assertIn("Father</textarea>", result)
         self.assertNotIn(
-            '<label for="id_speakers-0-last_name">Surname:</label>', result
+            '<label class="w-field__label" for="id_speakers-0-last_name" id="id_speakers-0-last_name-label">',
+            result,
         )
 
         # test for #338: surname field should not be rendered as a 'stray' label-less field
@@ -1211,7 +1126,10 @@ class TestInlinePanel(TestCase, WagtailTestUtils):
             allow_extra_attrs=True,
         )
 
-        self.assertIn('<label for="id_speakers-0-image">Image:</label>', result)
+        self.assertIn(
+            '<label class="w-field__label" for="id_speakers-0-image" id="id_speakers-0-image-label">',
+            result,
+        )
         self.assertIn("Choose an image", result)
 
         # rendered panel must also contain hidden fields for id, DELETE and ORDER
@@ -1282,6 +1200,29 @@ class TestInlinePanel(TestCase, WagtailTestUtils):
             )
 
 
+class TestInlinePanelGetComparison(TestCase):
+    fixtures = ["test.json"]
+
+    def setUp(self):
+        self.request = RequestFactory().get("/")
+        user = AnonymousUser()  # technically, Anonymous users cannot access the admin
+        self.request.user = user
+
+    def test_get_comparison(self):
+        # Test whether the InlinePanel passes it's label in get_comparison
+
+        page = Page.objects.get(id=4).specific
+        comparison = (
+            page.get_edit_handler()
+            .bind_to(instance=page, request=self.request)
+            .get_comparison()
+        )
+
+        comparison = [comp(page, page) for comp in comparison]
+        field_labels = [comp.field_label() for comp in comparison]
+        self.assertIn("Speakers", field_labels)
+
+
 class TestInlinePanelRelatedModelPanelConfigChecks(TestCase):
     def setUp(self):
         self.original_panels = EventPageSpeaker.panels
