@@ -46,8 +46,9 @@ class TestChooserBrowse(TestCase, WagtailTestUtils):
 
         with self.register_hook("construct_page_chooser_queryset", filter_pages):
             response = self.get()
-        self.assertEqual(len(response.context["pages"]), 1)
-        self.assertEqual(response.context["pages"][0].specific, page)
+        # 'results' in the template context consists of the parent page followed by the queryset
+        self.assertEqual(len(response.context["table"].data), 2)
+        self.assertEqual(response.context["table"].data[1].specific, page)
 
 
 class TestCanChooseRootFlag(TestCase, WagtailTestUtils):
@@ -126,7 +127,7 @@ class TestChooserBrowseChild(TestCase, WagtailTestUtils):
         self.assertTemplateUsed(response, "wagtailadmin/chooser/browse.html")
         self.assertEqual(response.context["page_type_string"], "tests.simplepage")
 
-        pages = {page.id: page for page in response.context["pages"].object_list}
+        pages = {page.id: page for page in response.context["table"].data}
 
         # Child page is a simple page directly underneath root
         # so should appear in the list
@@ -160,7 +161,7 @@ class TestChooserBrowseChild(TestCase, WagtailTestUtils):
         self.assertEqual(response.status_code, 200)
         self.assertTemplateUsed(response, "wagtailadmin/chooser/browse.html")
 
-        page_urls = [page.url for page in response.context["pages"]]
+        page_urls = [page.url for page in response.context["table"].data]
 
         self.assertIn("/foo/pointless-suffix/", page_urls)
 
@@ -190,7 +191,7 @@ class TestChooserBrowseChild(TestCase, WagtailTestUtils):
             response.context["page_type_string"], "tests.simplepage,tests.eventpage"
         )
 
-        pages = {page.id: page for page in response.context["pages"].object_list}
+        pages = {page.id: page for page in response.context["table"].data}
 
         # Simple page in results, as before
         self.assertIn(self.child_page.id, pages)
@@ -256,12 +257,13 @@ class TestChooserBrowseChild(TestCase, WagtailTestUtils):
 
         # Look for a link element in the breadcrumbs with the admin title
         expected = """
-            <li class="breadcrumb-item">
-                <a href="/admin/choose-page/{page_id}/?" class="breadcrumb-link navigate-pages">{page_title}
-                    <svg class="icon icon-arrow-right arrow_right_icon" aria-hidden="true">
-                        <use href="#icon-arrow-right"></use>
-                    </svg>
+            <li class="w-h-full w-flex w-items-center w-overflow-hidden w-transition w-duration-300 w-whitespace-nowrap w-flex-shrink-0 w-font-bold " data-breadcrumb-item>
+                <a class="w-flex w-items-center w-h-full w-text-primary w-px-0.5 w-text-14 w-no-underline w-outline-offset-inside hover:w-underline hover:w-text-primary w-h-full w-transition w-transition-all w-duration-300" href="/admin/choose-page/{page_id}/?">
+                    {page_title}
                 </a>
+                <svg class="icon icon-arrow-right w-w-4 w-h-4 w-ml-3" aria-hidden="true">
+                   <use href="#icon-arrow-right"></use>
+                </svg>
             </li>
         """.format(
             page_id=self.child_page.id,
@@ -283,26 +285,26 @@ class TestChooserBrowseChild(TestCase, WagtailTestUtils):
         self.setup_pagination_test_data()
 
         response = self.get()
-        self.assertEqual(response.context["pages"].paginator.num_pages, 5)
-        self.assertEqual(response.context["pages"].number, 1)
+        self.assertEqual(response.context["pagination_page"].paginator.num_pages, 5)
+        self.assertEqual(response.context["pagination_page"].number, 1)
 
     def test_pagination_another_page(self):
         self.setup_pagination_test_data()
 
         response = self.get({"p": 2})
-        self.assertEqual(response.context["pages"].number, 2)
+        self.assertEqual(response.context["pagination_page"].number, 2)
 
     def test_pagination_invalid_page(self):
         self.setup_pagination_test_data()
 
         response = self.get({"p": "foo"})
-        self.assertEqual(response.context["pages"].number, 1)
+        self.assertEqual(response.context["pagination_page"].number, 1)
 
     def test_pagination_out_of_range_page(self):
         self.setup_pagination_test_data()
 
         response = self.get({"p": 100})
-        self.assertEqual(response.context["pages"].number, 5)
+        self.assertEqual(response.context["pagination_page"].number, 5)
 
 
 class TestChooserSearch(TestCase, WagtailTestUtils):
@@ -1019,6 +1021,85 @@ class TestCanChoosePage(TestCase, WagtailTestUtils):
         )
         self.assertFalse(result)
 
+    def test_move_to_same_page(self):
+        homepage = Page.objects.get(url_path="/home/")
+        result = can_choose_page(
+            homepage,
+            self.permission_proxy,
+            self.desired_classes,
+            user_perm="move_to",
+            target_pages=[homepage],
+        )
+        self.assertFalse(result)
+
+    def test_move_to_root(self):
+        homepage = Page.objects.get(url_path="/home/")
+        root = Page.objects.get(url_path="/")
+        result = can_choose_page(
+            root,
+            self.permission_proxy,
+            self.desired_classes,
+            user_perm="move_to",
+            target_pages=[homepage],
+        )
+        self.assertTrue(result)
+
+    def test_move_to_page_with_wrong_parent_types(self):
+        board_meetings = Page.objects.get(
+            url_path="/home/events/businessy-events/board-meetings/"
+        )
+        homepage = Page.objects.get(url_path="/home/")
+        result = can_choose_page(
+            homepage,
+            self.permission_proxy,
+            self.desired_classes,
+            user_perm="move_to",
+            target_pages=[board_meetings],
+        )
+        self.assertFalse(result)
+
+    def test_move_to_same_page_bulk(self):
+        homepage = Page.objects.get(url_path="/home/")
+        secret_plans = Page.objects.get(url_path="/home/secret-plans/")
+        result = can_choose_page(
+            homepage,
+            self.permission_proxy,
+            self.desired_classes,
+            user_perm="bulk_move_to",
+            target_pages=[homepage, secret_plans],
+        )
+        self.assertFalse(result)
+
+    def test_move_to_root_bulk(self):
+        homepage = Page.objects.get(url_path="/home/")
+        secret_plans = Page.objects.get(url_path="/home/secret-plans/")
+        root = Page.objects.get(url_path="/")
+        result = can_choose_page(
+            root,
+            self.permission_proxy,
+            self.desired_classes,
+            user_perm="bulk_move_to",
+            target_pages=[homepage, secret_plans],
+        )
+        self.assertTrue(result)
+
+    def test_move_to_page_with_wrong_parent_types_bulk(self):
+        board_meetings = Page.objects.get(
+            url_path="/home/events/businessy-events/board-meetings/"
+        )
+        steal_underpants = Page.objects.get(
+            url_path="/home/secret-plans/steal-underpants/"
+        )
+        homepage = Page.objects.get(url_path="/home/")
+        result = can_choose_page(
+            homepage,
+            self.permission_proxy,
+            self.desired_classes,
+            user_perm="bulk_move_to",
+            target_pages=[board_meetings, steal_underpants],
+        )
+        self.assertTrue(result)
+
 
 @override_settings(WAGTAIL_I18N_ENABLED=True)
 class TestPageChooserLocaleSelector(TestCase, WagtailTestUtils):
