@@ -30,6 +30,16 @@ class TestLockedPagesView(TestCase, WagtailTestUtils):
         # Initially there should be no locked pages
         self.assertContains(response, "No locked pages found.")
 
+        # No user locked anything
+        self.assertInHTML(
+            """
+            <select name="locked_by" id="id_locked_by">
+                <option value="" selected>---------</option>
+            </select>
+            """,
+            response.content.decode(),
+        )
+
         self.page = Page.objects.first()
         self.page.locked = True
         self.page.locked_by = self.user
@@ -43,6 +53,16 @@ class TestLockedPagesView(TestCase, WagtailTestUtils):
         self.assertNotContains(response, "No locked pages found.")
         self.assertContains(response, self.page.title)
 
+        self.assertInHTML(
+            f"""
+            <select name="locked_by" id="id_locked_by">
+                <option value="" selected>---------</option>
+                <option value="{self.user.pk}">{self.user}</option>
+            </select>
+            """,
+            response.content.decode(),
+        )
+
     def test_csv_export(self):
 
         self.page = Page.objects.first()
@@ -262,6 +282,17 @@ class TestExcelDateFormatter(TestCase):
             with self.subTest(lang), translation.override(lang):
                 self.assertNotEqual(formatter.get(), "")
 
+    def test_format(self):
+        formatter = ExcelDateFormatter()
+
+        with self.subTest(format="r"):
+            # Format code for RFC 5322 formatted date, e.g. 'Thu, 21 Dec 2000 16:01:07'
+            self.assertEqual(formatter.format("r"), "ddd, d mmm yyyy hh:mm:ss")
+
+        with self.subTest(format="m/d/Y g:i A"):
+            # Format code for e.g. '12/21/2000 4:01 PM'
+            self.assertEqual(formatter.format("m/d/Y g:i A"), "mm/dd/yyyy h:mm AM/PM")
+
 
 class TestAgingPagesView(TestCase, WagtailTestUtils):
     def setUp(self):
