@@ -23,7 +23,7 @@ from wagtail.admin.views.pages import listing
 from wagtail.utils.urlpatterns import decorate_urlpatterns
 
 urlpatterns = [
-    path("", home.home, name="wagtailadmin_home"),
+    path("", home.HomeView.as_view(), name="wagtailadmin_home"),
     path("test404/", TemplateView.as_view(template_name="wagtailadmin/404.html")),
     path("api/", include(api_urls)),
     path("failwhale/", home.error_test, name="wagtailadmin_error_test"),
@@ -38,31 +38,35 @@ urlpatterns = [
     ),
     path("pages/", include(wagtailadmin_pages_urls, namespace="wagtailadmin_pages")),
     # TODO: Move into wagtailadmin_pages namespace
-    path("choose-page/", chooser.browse, name="wagtailadmin_choose_page"),
+    path("choose-page/", chooser.BrowseView.as_view(), name="wagtailadmin_choose_page"),
     path(
         "choose-page/<int:parent_page_id>/",
-        chooser.browse,
+        chooser.BrowseView.as_view(),
         name="wagtailadmin_choose_page_child",
     ),
-    path("choose-page/search/", chooser.search, name="wagtailadmin_choose_page_search"),
+    path(
+        "choose-page/search/",
+        chooser.SearchView.as_view(),
+        name="wagtailadmin_choose_page_search",
+    ),
     path(
         "choose-external-link/",
-        chooser.external_link,
+        chooser.ExternalLinkView.as_view(),
         name="wagtailadmin_choose_page_external_link",
     ),
     path(
         "choose-email-link/",
-        chooser.email_link,
+        chooser.EmailLinkView.as_view(),
         name="wagtailadmin_choose_page_email_link",
     ),
     path(
         "choose-phone-link/",
-        chooser.phone_link,
+        chooser.PhoneLinkView.as_view(),
         name="wagtailadmin_choose_page_phone_link",
     ),
     path(
         "choose-anchor-link/",
-        chooser.anchor_link,
+        chooser.AnchorLinkView.as_view(),
         name="wagtailadmin_choose_page_anchor_link",
     ),
     path("tag-autocomplete/", tags.autocomplete, name="wagtailadmin_tag_autocomplete"),
@@ -140,14 +144,14 @@ urlpatterns += [
 # This must be the last URL in this file!
 
 if settings.APPEND_SLASH:
-    # Only catch unrecognized patterns with a trailing slash
+    # Only catch unrecognised patterns with a trailing slash
     # and let CommonMiddleware handle adding a slash to every other pattern
     urlpatterns += [
         re_path(r"^.*/$", home.default),
     ]
 
 else:
-    # Catch all unrecognized patterns
+    # Catch all unrecognised patterns
     urlpatterns += [
         re_path(r"^", home.default),
     ]
