@@ -46,7 +46,7 @@ urlpatterns = [
     path("<int:page_id>/view_draft/", preview.view_draft, name="view_draft"),
     path("<int:parent_page_id>/add_subpage/", create.add_subpage, name="add_subpage"),
     path("<int:page_id>/delete/", delete.delete, name="delete"),
-    path("<int:page_id>/unpublish/", unpublish.unpublish, name="unpublish"),
+    path("<int:page_id>/unpublish/", unpublish.Unpublish.as_view(), name="unpublish"),
     path(
         "<int:page_id>/convert_alias/",
         convert_alias.convert_alias,
@@ -54,11 +54,6 @@ urlpatterns = [
     ),
     path("search/", search.search, name="search"),
     path("<int:page_to_move_id>/move/", move.move_choose_destination, name="move"),
-    path(
-        "<int:page_to_move_id>/move/<int:viewed_page_id>/",
-        move.move_choose_destination,
-        name="move_choose_destination",
-    ),
     path(
         "<int:page_to_move_id>/move/<int:destination_id>/confirm/",
         move.move_confirm,
@@ -116,7 +111,7 @@ urlpatterns = [
     path("<int:page_id>/revisions/", revisions.revisions_index, name="revisions_index"),
     path(
         "<int:page_id>/revisions/<int:revision_id>/view/",
-        revisions.revisions_view,
+        revisions.RevisionsView.as_view(),
         name="revisions_view",
     ),
     path(
@@ -131,7 +126,7 @@ urlpatterns = [
     ),
     re_path(
         r"^(\d+)/revisions/compare/(live|earliest|\d+)\.\.\.(live|latest|\d+)/$",
-        revisions.revisions_compare,
+        revisions.RevisionsCompare.as_view(),
         name="revisions_compare",
     ),
     path(
