@@ -10,7 +10,6 @@ from django.shortcuts import get_object_or_404, redirect
 from django.urls import reverse
 from django.utils import timezone
 from django.utils.html import format_html
-from django.utils.safestring import mark_safe
 from django.utils.translation import gettext as _
 from django.views.generic.base import ContextMixin, TemplateResponseMixin, View
 
@@ -18,10 +17,11 @@ from wagtail.actions.publish_page_revision import PublishPageRevisionAction
 from wagtail.admin import messages
 from wagtail.admin.action_menu import PageActionMenu
 from wagtail.admin.mail import send_notification
-from wagtail.admin.side_panels import PageSidePanels
+from wagtail.admin.ui.side_panels import PageSidePanels
 from wagtail.admin.views.generic import HookResponseMixin
 from wagtail.admin.views.pages.utils import get_valid_next_url_from_request
 from wagtail.exceptions import PageClassNotFoundError
+from wagtail.locks import BasicLock, ScheduledForPublishLock
 from wagtail.models import (
     COMMENTS_RELATION_NAME,
     Comment,
@@ -312,7 +312,9 @@ class EditView(TemplateResponseMixin, ContextMixin, HookResponseMixin, View):
             return self.page
 
     def dispatch(self, request, page_id):
-        self.real_page_record = get_object_or_404(Page, id=page_id)
+        self.real_page_record = get_object_or_404(
+            Page.objects.prefetch_workflow_states(), id=page_id
+        )
         self.latest_revision = self.real_page_record.get_latest_revision()
         self.page_content_type = self.real_page_record.cached_content_type
         self.page_class = self.real_page_record.specific_class
@@ -328,10 +330,14 @@ class EditView(TemplateResponseMixin, ContextMixin, HookResponseMixin, View):
                 "back to a branch where the model class is still present."
             )
 
-        self.page = self.real_page_record.get_latest_revision_as_page()
+        self.page = self.real_page_record.get_latest_revision_as_object()
         self.parent = self.page.get_parent()
 
         self.page_perms = self.page.permissions_for_user(self.request.user)
+        self.lock = self.page.get_lock()
+        self.locked_for_user = self.lock is not None and self.lock.for_user(
+            self.request.user
+        )
 
         if not self.page_perms.can_edit():
             raise PermissionDenied
@@ -373,79 +379,38 @@ class EditView(TemplateResponseMixin, ContextMixin, HookResponseMixin, View):
         return super().dispatch(request)
 
     def get(self, request):
-        if self.page_perms.user_has_lock():
-            if self.page.locked_at:
-                lock_message = format_html(
-                    _("<b>Page '{}' was locked</b> by <b>you</b> on <b>{}</b>."),
-                    self.page.get_admin_display_title(),
-                    self.page.locked_at.strftime("%d %b %Y %H:%M"),
-                )
-            else:
-                lock_message = format_html(
-                    _("<b>Page '{}' is locked</b> by <b>you</b>."),
-                    self.page.get_admin_display_title(),
-                )
-
-            lock_message += format_html(
-                '<span class="buttons"><button type="button" class="button button-small button-secondary" data-action-lock-unlock data-url="{}">{}</button></span>',
-                reverse("wagtailadmin_pages:unlock", args=(self.page.id,)),
-                _("Unlock"),
-            )
-            messages.warning(self.request, lock_message, extra_tags="lock")
-
-        elif self.page.locked and self.page_perms.page_locked():
-            # the page can also be locked at a permissions level if in a workflow, on a task the user is not a reviewer for
-            # this should be indicated separately
-            if self.page.locked_by and self.page.locked_at:
-                lock_message = format_html(
-                    _("<b>Page '{}' was locked</b> by <b>{}</b> on <b>{}</b>."),
-                    self.page.get_admin_display_title(),
-                    str(self.page.locked_by),
-                    self.page.locked_at.strftime("%d %b %Y %H:%M"),
-                )
-            else:
-                # Page was probably locked with an old version of Wagtail, or a script
-                lock_message = format_html(
-                    _("<b>Page '{}' is locked</b>."),
-                    self.page.get_admin_display_title(),
-                )
-
-            if self.page_perms.can_unlock():
-                lock_message += format_html(
-                    '<span class="buttons"><button type="button" class="button button-small button-secondary" data-action-lock-unlock data-url="{}">{}</button></span>',
-                    reverse("wagtailadmin_pages:unlock", args=(self.page.id,)),
-                    _("Unlock"),
-                )
-            messages.error(self.request, lock_message, extra_tags="lock")
-
-        if self.page.current_workflow_state:
-            workflow = self.workflow_state.workflow
-            task = self.workflow_state.current_task_state.task
-            if (
-                self.workflow_state.status != WorkflowState.STATUS_NEEDS_CHANGES
-                and task.specific.page_locked_for_user(self.page, self.request.user)
-            ):
-                # Check for revisions still undergoing moderation and warn
-                if len(self.workflow_tasks) == 1:
-                    # If only one task in workflow, show simple message
-                    workflow_info = _("This page is currently awaiting moderation.")
-                else:
-                    workflow_info = format_html(
-                        _(
-                            "This page is awaiting <b>'{}'</b> in the <b>'{}'</b> workflow."
-                        ),
-                        task.name,
-                        workflow.name,
+        if self.lock:
+            lock_message = self.lock.get_message(self.request.user)
+            if lock_message:
+                if isinstance(self.lock, BasicLock) and self.page_perms.can_unlock():
+                    lock_message = format_html(
+                        '{} <span class="buttons"><button type="button" class="button button-small button-secondary" data-action-lock-unlock data-url="{}">{}</button></span>',
+                        lock_message,
+                        reverse("wagtailadmin_pages:unlock", args=(self.page.id,)),
+                        _("Unlock"),
                     )
-                messages.error(
-                    self.request,
-                    mark_safe(
-                        workflow_info
-                        + " "
-                        + _("Only reviewers for this task can edit the page.")
-                    ),
-                    extra_tags="lock",
-                )
+
+                if (
+                    isinstance(self.lock, ScheduledForPublishLock)
+                    and self.page_perms.can_unschedule()
+                ):
+                    scheduled_revision = self.page.revisions.defer().get(
+                        approved_go_live_at__isnull=False
+                    )
+                    lock_message = format_html(
+                        '{} <span class="buttons"><button type="button" class="button button-small button-secondary" data-action-lock-unlock data-url="{}">{}</button></span>',
+                        lock_message,
+                        reverse(
+                            "wagtailadmin_pages:revisions_unschedule",
+                            args=[self.page.id, scheduled_revision.pk],
+                        ),
+                        _("Cancel scheduled publish"),
+                    )
+
+                if self.locked_for_user:
+                    messages.error(self.request, lock_message, extra_tags="lock")
+                else:
+                    messages.warning(self.request, lock_message, extra_tags="lock")
 
         self.form = self.form_class(
             instance=self.page,
@@ -494,7 +459,7 @@ class EditView(TemplateResponseMixin, ContextMixin, HookResponseMixin, View):
             and self.workflow_state.user_can_cancel(self.request.user)
         )
 
-        if self.form.is_valid() and not self.page_perms.page_locked():
+        if self.form.is_valid() and not self.locked_for_user:
             return self.form_valid(self.form)
         else:
             return self.form_invalid(self.form)
@@ -838,7 +803,7 @@ class EditView(TemplateResponseMixin, ContextMixin, HookResponseMixin, View):
             self.workflow_state.cancel(user=self.request.user)
             self.add_cancel_workflow_confirmation_message()
 
-        if self.page_perms.page_locked():
+        if self.locked_for_user:
             messages.error(
                 self.request, _("The page could not be saved as it is locked")
             )
@@ -867,10 +832,17 @@ class EditView(TemplateResponseMixin, ContextMixin, HookResponseMixin, View):
         bound_panel = self.edit_handler.get_bound_panel(
             instance=self.page, request=self.request, form=self.form
         )
-        action_menu = PageActionMenu(self.request, view="edit", page=self.page)
+        action_menu = PageActionMenu(
+            self.request,
+            view="edit",
+            page=self.page,
+            lock=self.lock,
+            locked_for_user=self.locked_for_user,
+        )
         side_panels = PageSidePanels(
             self.request,
             self.page_for_status,
+            preview_enabled=True,
             comments_enabled=self.form.show_comments_toggle,
         )
 
@@ -883,11 +855,10 @@ class EditView(TemplateResponseMixin, ContextMixin, HookResponseMixin, View):
                 "errors_debug": self.errors_debug,
                 "action_menu": action_menu,
                 "side_panels": side_panels,
-                "preview_modes": self.page.preview_modes,
                 "form": self.form,
                 "next": self.next_url,
                 "has_unsaved_changes": self.has_unsaved_changes,
-                "page_locked": self.page_perms.page_locked(),
+                "page_locked": self.locked_for_user,
                 "workflow_state": self.workflow_state
                 if self.workflow_state and self.workflow_state.is_active
                 else None,
