@@ -6,19 +6,19 @@ from django.views.decorators.http import require_GET
 
 from wagtail.admin import messages
 from wagtail.admin.mail import send_moderation_notification
-from wagtail.models import PageRevision
+from wagtail.models import Revision
 
 
 def approve_moderation(request, revision_id):
-    revision = get_object_or_404(PageRevision, id=revision_id)
-    if not revision.page.permissions_for_user(request.user).can_publish():
+    revision = get_object_or_404(Revision.page_revisions, id=revision_id)
+    if not revision.content_object.permissions_for_user(request.user).can_publish():
         raise PermissionDenied
 
     if not revision.submitted_for_moderation:
         messages.error(
             request,
             _("The page '{0}' is not currently awaiting moderation.").format(
-                revision.page.specific_deferred.get_admin_display_title()
+                revision.content_object.specific_deferred.get_admin_display_title()
             ),
         )
         return redirect("wagtailadmin_home")
@@ -27,16 +27,19 @@ def approve_moderation(request, revision_id):
         revision.approve_moderation(user=request.user)
 
         message = _("Page '{0}' published.").format(
-            revision.page.specific_deferred.get_admin_display_title()
+            revision.content_object.specific_deferred.get_admin_display_title()
         )
         buttons = []
-        if revision.page.url is not None:
+        if revision.content_object.url is not None:
             buttons.append(
-                messages.button(revision.page.url, _("View live"), new_window=False)
+                messages.button(
+                    revision.content_object.url, _("View live"), new_window=False
+                )
             )
         buttons.append(
             messages.button(
-                reverse("wagtailadmin_pages:edit", args=(revision.page.id,)), _("Edit")
+                reverse("wagtailadmin_pages:edit", args=(revision.content_object.id,)),
+                _("Edit"),
             )
         )
         messages.success(request, message, buttons=buttons)
@@ -48,15 +51,15 @@ def approve_moderation(request, revision_id):
 
 
 def reject_moderation(request, revision_id):
-    revision = get_object_or_404(PageRevision, id=revision_id)
-    if not revision.page.permissions_for_user(request.user).can_publish():
+    revision = get_object_or_404(Revision.page_revisions, id=revision_id)
+    if not revision.content_object.permissions_for_user(request.user).can_publish():
         raise PermissionDenied
 
     if not revision.submitted_for_moderation:
         messages.error(
             request,
             _("The page '{0}' is not currently awaiting moderation.").format(
-                revision.page.specific_deferred.get_admin_display_title()
+                revision.content_object.specific_deferred.get_admin_display_title()
             ),
         )
         return redirect("wagtailadmin_home")
@@ -67,11 +70,13 @@ def reject_moderation(request, revision_id):
         messages.success(
             request,
             _("Page '{0}' rejected for publication.").format(
-                revision.page.specific_deferred.get_admin_display_title()
+                revision.content_object.specific_deferred.get_admin_display_title()
             ),
             buttons=[
                 messages.button(
-                    reverse("wagtailadmin_pages:edit", args=(revision.page.id,)),
+                    reverse(
+                        "wagtailadmin_pages:edit", args=(revision.content_object.id,)
+                    ),
                     _("Edit"),
                 )
             ],
@@ -85,20 +90,20 @@ def reject_moderation(request, revision_id):
 
 @require_GET
 def preview_for_moderation(request, revision_id):
-    revision = get_object_or_404(PageRevision, id=revision_id)
-    if not revision.page.permissions_for_user(request.user).can_publish():
+    revision = get_object_or_404(Revision.page_revisions, id=revision_id)
+    if not revision.content_object.permissions_for_user(request.user).can_publish():
         raise PermissionDenied
 
     if not revision.submitted_for_moderation:
         messages.error(
             request,
             _("The page '{0}' is not currently awaiting moderation.").format(
-                revision.page.specific_deferred.get_admin_display_title()
+                revision.content_object.specific_deferred.get_admin_display_title()
             ),
         )
         return redirect("wagtailadmin_home")
 
-    page = revision.as_page_object()
+    page = revision.as_object()
 
     try:
         preview_mode = page.default_preview_mode
