@@ -3,12 +3,14 @@ from django.core.paginator import Paginator
 from django.http import Http404
 from django.template.response import TemplateResponse
 
-from wagtail.core.models import Page
+from wagtail.models import Page
 
 
 def content_type_use(request, content_type_app_name, content_type_model_name):
     try:
-        content_type = ContentType.objects.get_by_natural_key(content_type_app_name, content_type_model_name)
+        content_type = ContentType.objects.get_by_natural_key(
+            content_type_app_name, content_type_model_name
+        )
     except ContentType.DoesNotExist:
         raise Http404
 
@@ -21,11 +23,15 @@ def content_type_use(request, content_type_app_name, content_type_model_name):
     pages = page_class.objects.all().specific(defer=True)
 
     paginator = Paginator(pages, per_page=10)
-    pages = paginator.get_page(request.GET.get('p'))
+    pages = paginator.get_page(request.GET.get("p"))
 
-    return TemplateResponse(request, 'wagtailadmin/pages/content_type_use.html', {
-        'pages': pages,
-        'app_name': content_type_app_name,
-        'content_type': content_type,
-        'page_class': page_class,
-    })
+    return TemplateResponse(
+        request,
+        "wagtailadmin/pages/content_type_use.html",
+        {
+            "pages": pages,
+            "app_name": content_type_app_name,
+            "content_type": content_type,
+            "page_class": page_class,
+        },
+    )
