@@ -10,7 +10,11 @@ class ViewSetRegistry:
     def populate(self):
         for fn in hooks.get_hooks("register_admin_viewset"):
             viewset = fn()
-            self.register(viewset)
+            if isinstance(viewset, (list, tuple)):
+                for vs in viewset:
+                    self.register(vs)
+            else:
+                self.register(viewset)
 
     def register(self, viewset):
         self.viewsets.append(viewset)
