@@ -1,15 +1,15 @@
 from django.forms import widgets
 
-from wagtail.core.telepath import register
-from wagtail.core.widget_adapters import WidgetAdapter
+from wagtail.telepath import register
+from wagtail.widget_adapters import WidgetAdapter
 
 
 class AdminAutoHeightTextInput(widgets.Textarea):
-    template_name = 'wagtailadmin/widgets/auto_height_text_input.html'
+    template_name = "wagtailadmin/widgets/auto_height_text_input.html"
 
     def __init__(self, attrs=None):
         # Use more appropriate rows default, given autoheight will alter this anyway
-        default_attrs = {'rows': '1'}
+        default_attrs = {"rows": "1"}
         if attrs:
             default_attrs.update(attrs)
 
@@ -17,7 +17,7 @@ class AdminAutoHeightTextInput(widgets.Textarea):
 
 
 class AdminAutoHeightTextInputAdapter(WidgetAdapter):
-    js_constructor = 'wagtail.widgets.AdminAutoHeightTextInput'
+    js_constructor = "wagtail.widgets.AdminAutoHeightTextInput"
 
 
 register(AdminAutoHeightTextInputAdapter(), AdminAutoHeightTextInput)
