@@ -1,4 +1,5 @@
 import datetime
+from decimal import Decimal
 
 from django import forms
 from django.db.models.fields import BLANK_CHOICE_DASH
@@ -12,7 +13,11 @@ from django.utils.translation import gettext as _
 
 from wagtail.admin.staticfiles import versioned_static
 from wagtail.coreutils import camelcase_to_underscore, resolve_model_string
-from wagtail.rich_text import RichText, get_text_for_indexing
+from wagtail.rich_text import (
+    RichText,
+    RichTextMaxLengthValidator,
+    get_text_for_indexing,
+)
 from wagtail.telepath import Adapter, register
 
 from .base import Block
@@ -81,10 +86,9 @@ class FieldBlockAdapter(Adapter):
 
     def js_args(self, block):
         classname = [
-            "field",
-            camelcase_to_underscore(block.field.__class__.__name__),
-            "widget-" + camelcase_to_underscore(block.field.widget.__class__.__name__),
-            "fieldname-" + block.name,
+            "w-field",
+            f"w-field--{camelcase_to_underscore(block.field.__class__.__name__)}",
+            f"w-field--{camelcase_to_underscore(block.field.widget.__class__.__name__)}",
         ]
 
         form_classname = getattr(block.meta, "form_classname", "")
@@ -245,6 +249,9 @@ class DecimalBlock(FieldBlock):
         )
         super().__init__(*args, **kwargs)
 
+    def to_python(self, value):
+        return Decimal(value)
+
     class Meta:
         icon = "plus-inverse"
 
@@ -638,9 +645,14 @@ class RichTextBlock(FieldBlock):
         help_text=None,
         editor="default",
         features=None,
+        max_length=None,
         validators=(),
         **kwargs,
     ):
+        if max_length is not None:
+            validators = list(validators) + [
+                RichTextMaxLengthValidator(max_length),
+            ]
         self.field_options = {
             "required": required,
             "help_text": help_text,
@@ -744,10 +756,14 @@ class ChooserBlock(FieldBlock):
 
     """Abstract superclass for fields that implement a chooser interface (page, image, snippet etc)"""
 
+    @cached_property
+    def model_class(self):
+        return resolve_model_string(self.target_model)
+
     @cached_property
     def field(self):
         return forms.ModelChoiceField(
-            queryset=self.target_model.objects.all(),
+            queryset=self.model_class.objects.all(),
             widget=self.widget,
             required=self._required,
             validators=self._validators,
@@ -760,8 +776,8 @@ class ChooserBlock(FieldBlock):
             return value
         else:
             try:
-                return self.target_model.objects.get(pk=value)
-            except self.target_model.DoesNotExist:
+                return self.model_class.objects.get(pk=value)
+            except self.model_class.DoesNotExist:
                 return None
 
     def bulk_to_python(self, values):
@@ -769,7 +785,7 @@ class ChooserBlock(FieldBlock):
 
         The instances must be returned in the same order as the values and keep None values.
         """
-        objects = self.target_model.objects.in_bulk(values)
+        objects = self.model_class.objects.in_bulk(values)
         return [
             objects.get(id) for id in values
         ]  # Keeps the ordering the same as in values.
@@ -783,14 +799,17 @@ class ChooserBlock(FieldBlock):
 
     def value_from_form(self, value):
         # ModelChoiceField sometimes returns an ID, and sometimes an instance; we want the instance
-        if value is None or isinstance(value, self.target_model):
+        if value is None or isinstance(value, self.model_class):
             return value
         else:
             try:
-                return self.target_model.objects.get(pk=value)
-            except self.target_model.DoesNotExist:
+                return self.model_class.objects.get(pk=value)
+            except self.model_class.DoesNotExist:
                 return None
 
+    def get_form_state(self, value):
+        return self.widget.get_value_data(value)
+
     def clean(self, value):
         # ChooserBlock works natively with model instances as its 'value' type (because that's what you
         # want to work with when doing front-end templating), but ModelChoiceField.clean expects an ID
@@ -799,7 +818,7 @@ class ChooserBlock(FieldBlock):
         # type) so we convert our instance back to an ID here. It means we have a wasted round-trip to
         # the database when ModelChoiceField.clean promptly does its own lookup, but there's no easy way
         # around that...
-        if isinstance(value, self.target_model):
+        if isinstance(value, self.model_class):
             value = value.pk
         return super().clean(value)
 
