@@ -59,7 +59,7 @@ class AbstractFormSubmission(models.Model):
         }
 
     def __str__(self):
-        return self.form_data
+        return f"{self.form_data}"
 
     class Meta:
         abstract = True
@@ -121,6 +121,16 @@ class AbstractFormField(Orderable):
         FieldPanel("default_value", classname="formbuilder-default"),
     ]
 
+    def get_field_clean_name(self):
+        """
+        Prepare an ascii safe lower_snake_case variant of the field name to use as the field key.
+        This key is used to reference the field responses in the JSON store and as the field name in forms.
+        Called for new field creation, validation of duplicate labels and form previews.
+        When called, does not have access to the Page, nor its own id as the record is not yet created.
+        """
+
+        return get_field_clean_name(self.label)
+
     def save(self, *args, **kwargs):
         """
         When new fields are created, generate a template safe ascii name to use as the
@@ -132,7 +142,7 @@ class AbstractFormField(Orderable):
 
         is_new = self.pk is None
         if is_new:
-            clean_name = get_field_clean_name(self.label)
+            clean_name = self.get_field_clean_name()
             self.clean_name = clean_name
 
         super().save(*args, **kwargs)
@@ -279,12 +289,15 @@ class AbstractForm(Page):
 
     def serve_preview(self, request, mode_name):
         if mode_name == "landing":
-            request.is_preview = True
-            request.preview_mode = mode_name
             return self.render_landing_page(request)
         else:
             return super().serve_preview(request, mode_name)
 
+    def get_preview_context(self, request, mode_name):
+        context = super().get_preview_context(request, mode_name)
+        context["form"] = self.get_form(page=self, user=request.user)
+        return context
+
 
 def validate_to_address(value):
     for address in value.split(","):
