@@ -12,7 +12,9 @@ from django.utils.safestring import mark_safe
 from wagtail import hooks
 from wagtail.admin.admin_url_finder import register_admin_url_finder
 from wagtail.admin.checks import check_panels_in_model
+from wagtail.admin.menu import Menu
 from wagtail.admin.panels import ObjectList, extract_panel_definitions_from_model_class
+from wagtail.coreutils import accepts_kwarg
 from wagtail.models import Page, TranslatableMixin
 from wagtail.utils.deprecation import RemovedInWagtail50Warning
 
@@ -26,7 +28,7 @@ from .helpers import (
     PagePermissionHelper,
     PermissionHelper,
 )
-from .menus import GroupMenuItem, ModelAdminMenuItem, SubMenu
+from .menus import GroupMenuItem, ModelAdminMenuItem
 from .mixins import ThumbnailMixin  # NOQA
 from .views import (
     ChooseParentView,
@@ -46,6 +48,7 @@ class WagtailRegisterable:
     """
 
     add_to_settings_menu = False
+    add_to_admin_menu = True
     exclude_from_explorer = False
 
     def register_with_wagtail(self):
@@ -57,15 +60,18 @@ class WagtailRegisterable:
         def register_admin_urls():
             return self.get_admin_urls_for_registration()
 
-        menu_hook = (
-            "register_settings_menu_item"
-            if self.add_to_settings_menu
-            else "register_admin_menu_item"
-        )
+        if self.add_to_settings_menu:
+            menu_hook = "register_settings_menu_item"
+        elif self.add_to_admin_menu:
+            menu_hook = "register_admin_menu_item"
+        else:
+            menu_hook = None
 
-        @hooks.register(menu_hook)
-        def register_admin_menu_item():
-            return self.get_menu_item()
+        if menu_hook:
+
+            @hooks.register(menu_hook)
+            def register_admin_menu_item():
+                return self.get_menu_item()
 
         # Overriding the explorer page queryset is a somewhat 'niche' / experimental
         # operation, so only attach that hook if we specifically opt into it
@@ -98,6 +104,7 @@ class ModelAdmin(WagtailRegisterable):
 
     model = None
     menu_label = None
+    menu_item_name = None
     menu_icon = None
     menu_order = None
     list_display = ("__str__",)
@@ -141,6 +148,7 @@ class ModelAdmin(WagtailRegisterable):
     form_view_extra_css = []
     form_view_extra_js = []
     form_fields_exclude = []
+    base_url_path = None
 
     def __init__(self, parent=None):
         """
@@ -157,7 +165,18 @@ class ModelAdmin(WagtailRegisterable):
         self.permission_helper = self.get_permission_helper_class()(
             self.model, self.inspect_view_enabled
         )
-        self.url_helper = self.get_url_helper_class()(self.model)
+        url_helper_class = self.get_url_helper_class()
+        if accepts_kwarg(url_helper_class, "base_url_path"):
+            self.url_helper = url_helper_class(
+                self.model, base_url_path=self.base_url_path
+            )
+        else:
+            warn(
+                "%s.__init__ needs to be updated to accept a `base_url_path` keyword argument"
+                % url_helper_class.__name__,
+                category=RemovedInWagtail50Warning,
+            )
+            self.url_helper = url_helper_class(self.model)
 
         # Needed to support RelatedFieldListFilter
         # See: https://github.com/wagtail/wagtail/issues/5105
@@ -198,6 +217,12 @@ class ModelAdmin(WagtailRegisterable):
         """
         return self.menu_label or self.opts.verbose_name_plural.title()
 
+    def get_menu_item_name(self):
+        """
+        Returns the name to be used for the menu item.
+        """
+        return self.menu_item_name
+
     def get_menu_icon(self):
         """
         Returns the icon to be used for the menu item. The value is prepended
@@ -352,9 +377,7 @@ class ModelAdmin(WagtailRegisterable):
         return self.form_fields_exclude
 
     def get_index_view_extra_css(self):
-        css = ["wagtailmodeladmin/css/index.css"]
-        css.extend(self.index_view_extra_css)
-        return css
+        return self.index_view_extra_css
 
     def get_index_view_extra_js(self):
         return self.index_view_extra_js
@@ -576,7 +599,7 @@ class ModelAdmin(WagtailRegisterable):
         """
         Utilised by Wagtail's 'register_menu_item' hook to create a menu item
         to access the listing view, or can be called by ModelAdminGroup
-        to create a SubMenu
+        to create a submenu
         """
         return ModelAdminMenuItem(self, order or self.get_menu_order())
 
@@ -677,12 +700,13 @@ class ModelAdmin(WagtailRegisterable):
 class ModelAdminGroup(WagtailRegisterable):
     """
     Acts as a container for grouping together mutltiple PageModelAdmin and
-    SnippetModelAdmin instances. Creates a menu item with a SubMenu for
+    SnippetModelAdmin instances. Creates a menu item with a submenu for
     accessing the listing pages of those instances
     """
 
     items = ()
     menu_label = None
+    menu_item_name = None
     menu_order = None
     menu_icon = None
 
@@ -699,6 +723,9 @@ class ModelAdminGroup(WagtailRegisterable):
     def get_menu_label(self):
         return self.menu_label or self.get_app_label_from_subitems()
 
+    def get_menu_item_name(self):
+        return self.menu_item_name
+
     def get_app_label_from_subitems(self):
         for instance in self.modeladmin_instances:
             return instance.opts.app_label.title()
@@ -713,11 +740,11 @@ class ModelAdminGroup(WagtailRegisterable):
     def get_menu_item(self):
         """
         Utilised by Wagtail's 'register_menu_item' hook to create a menu
-        for this group with a SubMenu linking to listing pages for any
+        for this group with a submenu linking to listing pages for any
         associated ModelAdmin instances
         """
         if self.modeladmin_instances:
-            submenu = SubMenu(self.get_submenu_items())
+            submenu = Menu(items=self.get_submenu_items())
             return GroupMenuItem(self, self.get_menu_order(), submenu)
 
     def get_submenu_items(self):
