@@ -2,7 +2,7 @@ import datetime
 from io import BytesIO
 from unittest import mock
 
-from django.contrib.auth.models import Group
+from django.contrib.auth.models import Group, Permission
 from django.contrib.contenttypes.models import ContentType
 from django.core import checks
 from django.test import TestCase
@@ -24,7 +24,7 @@ from wagtail.test.modeladmintest.models import (
     Token,
     TranslatableBook,
 )
-from wagtail.test.modeladmintest.wagtail_hooks import BookModelAdmin
+from wagtail.test.modeladmintest.wagtail_hooks import BookModelAdmin, EventsAdminGroup
 from wagtail.test.utils import WagtailTestUtils
 
 
@@ -263,6 +263,39 @@ class TestAuthorIndexView(TestCase, WagtailTestUtils):
         """
         self.assertContains(response, test_html, html=True)
 
+    def test_title_column_links_to_edit_view_by_default(self):
+        response = self.get()
+        self.assertEqual(response.status_code, 200)
+        test_html = """
+            <div class="title-wrapper"><a href="/admin/modeladmintest/author/edit/1/" title="Edit this author">J. R. R. Tolkien</a></div>
+        """
+        self.assertContains(response, test_html, html=True)
+
+    @mock.patch(
+        "wagtail.contrib.modeladmin.helpers.permission.PermissionHelper.user_can_edit_obj",
+        return_value=False,
+    )
+    def test_title_column_links_to_inspect_view_when_user_cannot_edit(self, *mocks):
+        response = self.get()
+        self.assertEqual(response.status_code, 200)
+        test_html = """
+            <div class="title-wrapper"><a href="/admin/modeladmintest/author/inspect/1/" title="Inspect this author">J. R. R. Tolkien</a></div>
+        """
+        self.assertContains(response, test_html, html=True)
+
+    @mock.patch(
+        "wagtail.contrib.modeladmin.helpers.permission.PermissionHelper.user_can_inspect_obj",
+        return_value=False,
+    )
+    @mock.patch(
+        "wagtail.contrib.modeladmin.helpers.permission.PermissionHelper.user_can_edit_obj",
+        return_value=False,
+    )
+    def test_title_column_is_not_linked_when_user_cannot_edit_or_inspect(self, *mocks):
+        response = self.get()
+        self.assertEqual(response.status_code, 200)
+        self.assertContains(response, '<td class="field-name title">J. R. R. Tolkien')
+
 
 @override_settings(WAGTAIL_I18N_ENABLED=True)
 class TestTranslatableBookIndexView(TestCase, WagtailTestUtils):
@@ -376,12 +409,7 @@ class TestCreateView(TestCase, WagtailTestUtils):
 
         # Check that a form error was raised
         self.assertFormError(response, "form", "title", "This field is required.")
-        self.assertContains(
-            response,
-            """<p class="error-message"><span>This field is required.</span></p>""",
-            count=1,
-            html=True,
-        )
+        self.assertContains(response, "error-message", count=1)
 
     def test_exclude_passed_to_extract_panel_definitions(self):
         path_to_form_fields_exclude_property = (
@@ -465,6 +493,36 @@ class TestTranslatableCreateView(TestCase, WagtailTestUtils):
         self.assertContains(response, expected, html=True)
 
 
+class TestRevisableCreateView(TestCase, WagtailTestUtils):
+    def setUp(self):
+        self.login()
+
+    def post(self, post_data):
+        return self.client.post("/admin/modeladmintest/publisher/create/", post_data)
+
+    def test_create_with_revision(self):
+        data = {"name": "foo"}
+        response = self.post(data)
+        self.assertRedirects(response, "/admin/modeladmintest/publisher/")
+
+        instances = Publisher.objects.filter(name="foo")
+        instance = instances.first()
+        self.assertEqual(instances.count(), 1)
+
+        # The revision should be created
+        revisions = instance.revisions
+        revision = revisions.first()
+        self.assertEqual(revisions.count(), 1)
+        self.assertEqual(revision.content["name"], "foo")
+
+        # The log entry should have the revision attached
+        log_entries = ModelLogEntry.objects.for_instance(instance).filter(
+            action="wagtail.create"
+        )
+        self.assertEqual(log_entries.count(), 1)
+        self.assertEqual(log_entries.first().revision, revision)
+
+
 class TestInspectView(TestCase, WagtailTestUtils):
     fixtures = ["modeladmintest_test.json"]
 
@@ -530,6 +588,21 @@ class TestInspectView(TestCase, WagtailTestUtils):
         response = self.get_for_book(100)
         self.assertEqual(response.status_code, 404)
 
+    def test_back_to_listing(self):
+        response = self.client.get("/admin/modeladmintest/author/inspect/1/")
+        # check that back to listing link exists
+        expected = """
+            <p class="back">
+                    <a href="/admin/modeladmintest/author/">
+                        <svg class="icon icon-arrow-left default" aria-hidden="true">
+                            <use href="#icon-arrow-left"></use>
+                        </svg>
+                        Back to author list
+                    </a>
+            </p>
+        """
+        self.assertContains(response, expected, html=True)
+
 
 class TestEditView(TestCase, WagtailTestUtils):
     fixtures = ["modeladmintest_test.json"]
@@ -605,12 +678,7 @@ class TestEditView(TestCase, WagtailTestUtils):
 
         # Check that a form error was raised
         self.assertFormError(response, "form", "title", "This field is required.")
-        self.assertContains(
-            response,
-            """<p class="error-message"><span>This field is required.</span></p>""",
-            count=1,
-            html=True,
-        )
+        self.assertContains(response, "error-message", count=1)
 
     def test_exclude_passed_to_extract_panel_definitions(self):
         path_to_form_fields_exclude_property = (
@@ -701,6 +769,39 @@ class TestTranslatableBookEditView(TestCase, WagtailTestUtils):
         self.assertContains(response, expected, html=True)
 
 
+class TestRevisableEditView(TestCase, WagtailTestUtils):
+    def setUp(self):
+        self.login()
+        self.instance = Publisher.objects.create(name="foo")
+
+    def post(self, post_data):
+        return self.client.post(
+            "/admin/modeladmintest/publisher/edit/%s/" % self.instance.pk, post_data
+        )
+
+    def test_edit_with_revision(self):
+        data = {"name": "bar"}
+        response = self.post(data)
+        self.assertRedirects(response, "/admin/modeladmintest/publisher/")
+
+        instances = Publisher.objects.filter(name="bar")
+        instance = instances.first()
+        self.assertEqual(instances.count(), 1)
+
+        # The revision should be created
+        revisions = instance.revisions
+        revision = revisions.first()
+        self.assertEqual(revisions.count(), 1)
+        self.assertEqual(revision.content["name"], "bar")
+
+        # The log entry should have the revision attached
+        log_entries = ModelLogEntry.objects.for_instance(instance).filter(
+            action="wagtail.edit"
+        )
+        self.assertEqual(log_entries.count(), 1)
+        self.assertEqual(log_entries.first().revision, revision)
+
+
 class TestPageSpecificViews(TestCase, WagtailTestUtils):
     fixtures = ["modeladmintest_test.json"]
     expected_status_code = 404
@@ -819,41 +920,102 @@ class TestEditorAccess(TestCase, WagtailTestUtils):
 
     def setUp(self):
         # Create a user
-        user = self.create_user(username="test2", password="password")
-        user.groups.add(Group.objects.get(pk=2))
-        self.user = user
+        self.user = self.create_user(username="test2", password="password")
+        self.group = Group.objects.get(name="Editors")
+        self.user.groups.add(self.group)
+        self.book_content_type = ContentType.objects.get_for_model(Book)
+
         # Login
         self.login(username="test2", password="password")
 
-        return user
-
     def test_index_permitted(self):
         response = self.client.get("/admin/modeladmintest/book/")
         self.assertRedirects(response, "/admin/")
 
-    def test_inpspect_permitted(self):
+        self.group.permissions.add(
+            Permission.objects.get(
+                codename="add_book", content_type=self.book_content_type
+            )
+        )
+        response = self.client.get("/admin/modeladmintest/book/")
+        self.assertEqual(response.status_code, 200)
+
+    def test_inspect_permitted(self):
         response = self.client.get("/admin/modeladmintest/book/inspect/2/")
         self.assertRedirects(response, "/admin/")
 
+        self.group.permissions.add(
+            Permission.objects.get(
+                codename="add_book", content_type=self.book_content_type
+            )
+        )
+        response = self.client.get("/admin/modeladmintest/book/inspect/2/")
+        self.assertEqual(response.status_code, 200)
+
     def test_create_permitted(self):
         response = self.client.get("/admin/modeladmintest/book/create/")
         self.assertRedirects(response, "/admin/")
 
+        self.group.permissions.add(
+            Permission.objects.get(
+                codename="add_book", content_type=self.book_content_type
+            )
+        )
+        response = self.client.get("/admin/modeladmintest/book/create/")
+        self.assertEqual(response.status_code, 200)
+
     def test_edit_permitted(self):
         response = self.client.get("/admin/modeladmintest/book/edit/2/")
         self.assertRedirects(response, "/admin/")
 
+        self.group.permissions.add(
+            Permission.objects.get(
+                codename="change_book", content_type=self.book_content_type
+            )
+        )
+        response = self.client.get("/admin/modeladmintest/book/edit/2/")
+        self.assertEqual(response.status_code, 200)
+
+    def test_admin_url_finder_without_permission(self):
         url_finder = AdminURLFinder(self.user)
         self.assertIsNone(url_finder.get_edit_url(Book.objects.get(id=2)))
 
+    def test_admin_url_finder_with_permission(self):
+        self.group.permissions.add(
+            Permission.objects.get(
+                codename="change_book", content_type=self.book_content_type
+            )
+        )
+        url_finder = AdminURLFinder(self.user)
+        self.assertEqual(
+            url_finder.get_edit_url(Book.objects.get(id=2)),
+            "/admin/modeladmintest/book/edit/2/",
+        )
+
     def test_delete_get_permitted(self):
         response = self.client.get("/admin/modeladmintest/book/delete/2/")
         self.assertRedirects(response, "/admin/")
 
+        self.group.permissions.add(
+            Permission.objects.get(
+                codename="delete_book", content_type=self.book_content_type
+            )
+        )
+        response = self.client.get("/admin/modeladmintest/book/delete/2/")
+        self.assertEqual(response.status_code, 200)
+
     def test_delete_post_permitted(self):
         response = self.client.post("/admin/modeladmintest/book/delete/2/")
         self.assertRedirects(response, "/admin/")
 
+        self.group.permissions.add(
+            Permission.objects.get(
+                codename="delete_book", content_type=self.book_content_type
+            )
+        )
+        response = self.client.post("/admin/modeladmintest/book/delete/2/")
+        self.assertRedirects(response, "/admin/modeladmintest/book/")
+
 
 class TestHistoryView(TestCase, WagtailTestUtils):
     fixtures = ["modeladmintest_test.json"]
@@ -874,7 +1036,7 @@ class TestHistoryView(TestCase, WagtailTestUtils):
         self.assertContains(response, "<td>Created</td>", html=True)
         self.assertContains(
             response,
-            '<div class="human-readable-date" title="Sept. 30, 2021, 10:01 a.m.">',
+            'data-tippy-content="Sept. 30, 2021, 10:01 a.m."',
         )
 
 
@@ -911,48 +1073,6 @@ class TestQuoting(TestCase, WagtailTestUtils):
         self.assertEqual(response.status_code, 200)
 
 
-class TestHeaderBreadcrumbs(TestCase, WagtailTestUtils):
-    """
-    Test that the breadcrumbs region is inserted before the
-    </header> tag for potential future regression.
-    See https://github.com/wagtail/wagtail/issues/3889
-    """
-
-    fixtures = ["modeladmintest_test.json"]
-
-    def setUp(self):
-        self.login()
-
-    def test_choose_inspect_model(self):
-        response = self.client.get("/admin/modeladmintest/author/inspect/1/")
-
-        # check correct templates were used
-        self.assertTemplateUsed(response, "modeladmin/includes/breadcrumb.html")
-        self.assertTemplateUsed(response, "wagtailadmin/shared/header.html")
-
-        # check that home breadcrumb link exists
-        expected = """
-            <li class="breadcrumb-item home">
-                <a href="/admin/" class="breadcrumb-link">
-                    <svg class="icon icon-home home_icon" aria-hidden="true">
-                        <use href="#icon-home"></use>
-                    </svg>
-                    <span class="visuallyhidden">Home</span>
-                    <svg class="icon icon-arrow-right arrow_right_icon" aria-hidden="true">
-                        <use href="#icon-arrow-right"></use>
-                    </svg>
-                </a>
-            </li>
-        """
-        self.assertContains(response, expected, html=True)
-
-        # check that the breadcrumbs are before the first header closing tag
-        content_str = str(response.content)
-        position_of_header_close = content_str.index("</header>")
-        position_of_breadcrumbs = content_str.index('<ul class="breadcrumb">')
-        self.assertGreater(position_of_header_close, position_of_breadcrumbs)
-
-
 class TestPanelConfigurationChecks(TestCase, WagtailTestUtils):
     def setUp(self):
         self.warning_id = "wagtailadmin.W002"
@@ -1029,3 +1149,42 @@ There are no default tabs on non-Page models so there will be no\
         # clean up for future checks
         delattr(Publisher, "content_panels")
         delattr(Publisher, "edit_handler")
+
+
+class TestMenuSetting(TestCase, WagtailTestUtils):
+    fixtures = ["modeladmintest_test.json"]
+
+    def setUp(self):
+        self.login()
+
+    def test_default_menu_setting_model_admin(self):
+        modeladmin = BookModelAdmin()
+
+        menu_item = modeladmin.get_menu_item()
+        self.assertEqual(menu_item.label, "Books")
+        self.assertEqual(menu_item.name, "books")
+
+    def test_custom_menu_setting_model_admin(self):
+        modeladmin = BookModelAdmin()
+        modeladmin.menu_label = "Book Model Label"
+        modeladmin.menu_item_name = "bookitem"
+
+        menu_item = modeladmin.get_menu_item()
+        self.assertEqual(menu_item.label, "Book Model Label")
+        self.assertEqual(menu_item.name, "bookitem")
+
+    def test_default_menu_setting_model_admin_group(self):
+        modeladmin = EventsAdminGroup()
+
+        menu_item = modeladmin.get_menu_item()
+        self.assertEqual(menu_item.label, "Events")
+        self.assertEqual(menu_item.name, "events")
+
+    def test_custom_menu_setting_model_admin_group(self):
+        modeladmin = EventsAdminGroup()
+        modeladmin.menu_label = "Event Model Label"
+        modeladmin.menu_item_name = "eventitem"
+
+        menu_item = modeladmin.get_menu_item()
+        self.assertEqual(menu_item.label, "Event Model Label")
+        self.assertEqual(menu_item.name, "eventitem")
