@@ -23,7 +23,7 @@ ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 """
-# https://raw.githubusercontent.com/django-import-export/django-import-export/master/import_export/formats/base_formats.py
+# https://raw.githubusercontent.com/django-import-export/django-import-export/main/import_export/formats/base_formats.py
 from importlib import import_module
 
 import tablib
@@ -55,7 +55,7 @@ class Format:
         """
         Returns mode for opening files.
         """
-        return 'rb'
+        return "rb"
 
     def get_extension(self):
         """
@@ -66,7 +66,7 @@ class Format:
     def get_content_type(self):
         # For content types see
         # https://www.iana.org/assignments/media-types/media-types.xhtml
-        return 'application/octet-stream'
+        return "application/octet-stream"
 
     @classmethod
     def is_available(cls):
@@ -81,7 +81,7 @@ class Format:
 
 class TablibFormat(Format):
     TABLIB_MODULE = None
-    CONTENT_TYPE = 'application/octet-stream'
+    CONTENT_TYPE = "application/octet-stream"
 
     def get_format(self):
         """
@@ -93,7 +93,7 @@ class TablibFormat(Format):
         except ImportError:
             return import_module(self.TABLIB_MODULE)
         else:
-            key = self.TABLIB_MODULE.split('.')[-1].replace('_', '')
+            key = self.TABLIB_MODULE.split(".")[-1].replace("_", "")
             return registry.get_format(key)
 
     @classmethod
@@ -120,66 +120,67 @@ class TablibFormat(Format):
         return self.CONTENT_TYPE
 
     def can_import(self):
-        return hasattr(self.get_format(), 'import_set')
+        return hasattr(self.get_format(), "import_set")
 
     def can_export(self):
-        return hasattr(self.get_format(), 'export_set')
+        return hasattr(self.get_format(), "export_set")
 
 
 class TextFormat(TablibFormat):
     def get_read_mode(self):
-        return 'r'
+        return "r"
 
     def is_binary(self):
         return False
 
 
 class CSV(TextFormat):
-    TABLIB_MODULE = 'tablib.formats._csv'
-    CONTENT_TYPE = 'text/csv'
+    TABLIB_MODULE = "tablib.formats._csv"
+    CONTENT_TYPE = "text/csv"
 
     def create_dataset(self, in_stream, **kwargs):
         return super().create_dataset(in_stream, **kwargs)
 
 
 class JSON(TextFormat):
-    TABLIB_MODULE = 'tablib.formats._json'
-    CONTENT_TYPE = 'application/json'
+    TABLIB_MODULE = "tablib.formats._json"
+    CONTENT_TYPE = "application/json"
 
 
 class YAML(TextFormat):
-    TABLIB_MODULE = 'tablib.formats._yaml'
+    TABLIB_MODULE = "tablib.formats._yaml"
     # See https://stackoverflow.com/questions/332129/yaml-mime-type
-    CONTENT_TYPE = 'text/yaml'
+    CONTENT_TYPE = "text/yaml"
 
 
 class TSV(TextFormat):
-    TABLIB_MODULE = 'tablib.formats._tsv'
-    CONTENT_TYPE = 'text/tab-separated-values'
+    TABLIB_MODULE = "tablib.formats._tsv"
+    CONTENT_TYPE = "text/tab-separated-values"
 
     def create_dataset(self, in_stream, **kwargs):
         return super().create_dataset(in_stream, **kwargs)
 
 
 class ODS(TextFormat):
-    TABLIB_MODULE = 'tablib.formats._ods'
-    CONTENT_TYPE = 'application/vnd.oasis.opendocument.spreadsheet'
+    TABLIB_MODULE = "tablib.formats._ods"
+    CONTENT_TYPE = "application/vnd.oasis.opendocument.spreadsheet"
 
 
 class HTML(TextFormat):
-    TABLIB_MODULE = 'tablib.formats._html'
-    CONTENT_TYPE = 'text/html'
+    TABLIB_MODULE = "tablib.formats._html"
+    CONTENT_TYPE = "text/html"
 
 
 class XLS(TablibFormat):
-    TABLIB_MODULE = 'tablib.formats._xls'
-    CONTENT_TYPE = 'application/vnd.ms-excel'
+    TABLIB_MODULE = "tablib.formats._xls"
+    CONTENT_TYPE = "application/vnd.ms-excel"
 
     def create_dataset(self, in_stream):
         """
         Create dataset from first sheet.
         """
         import xlrd
+
         xls_book = xlrd.open_workbook(file_contents=in_stream)
         dataset = tablib.Dataset()
         sheet = xls_book.sheets()[0]
@@ -191,8 +192,8 @@ class XLS(TablibFormat):
 
 
 class XLSX(TablibFormat):
-    TABLIB_MODULE = 'tablib.formats._xlsx'
-    CONTENT_TYPE = 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet'
+    TABLIB_MODULE = "tablib.formats._xlsx"
+    CONTENT_TYPE = "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet"
 
     def create_dataset(self, in_stream):
         """
@@ -201,6 +202,7 @@ class XLSX(TablibFormat):
         from io import BytesIO
 
         import openpyxl
+
         xlsx_book = openpyxl.load_workbook(BytesIO(in_stream), read_only=True)
 
         dataset = tablib.Dataset()
@@ -218,13 +220,17 @@ class XLSX(TablibFormat):
 
 #: These are the default formats for import and export. Whether they can be
 #: used or not is depending on their implementation in the tablib library.
-DEFAULT_FORMATS = [fmt for fmt in (
-    CSV,
-    XLS,
-    XLSX,
-    TSV,
-    ODS,
-    JSON,
-    YAML,
-    HTML,
-) if fmt.is_available()]
+DEFAULT_FORMATS = [
+    fmt
+    for fmt in (
+        CSV,
+        XLS,
+        XLSX,
+        TSV,
+        ODS,
+        JSON,
+        YAML,
+        HTML,
+    )
+    if fmt.is_available()
+]
