@@ -1,11 +1,12 @@
 from django.utils.functional import SimpleLazyObject
 
+from wagtail.contrib.settings.models import BaseGenericSetting, BaseSiteSetting
 from wagtail.models import Site
 
 from .registry import registry
 
 
-class SettingsProxy(dict):
+class SettingProxy(dict):
     """
     Get a SettingModuleProxy for an app using proxy['app_label']
     """
@@ -17,13 +18,10 @@ class SettingsProxy(dict):
         self[app_label] = value = SettingModuleProxy(self.request_or_site, app_label)
         return value
 
-    def __str__(self):
-        return "SettingsProxy"
-
 
 class SettingModuleProxy(dict):
     """
-    Get a setting instance using proxy['modelname']
+    Get a specific setting instance using proxy['modelname']
     """
 
     def __init__(self, request_or_site, app_label):
@@ -40,33 +38,48 @@ class SettingModuleProxy(dict):
         self[model_name] = value = self.get_setting(model_name)
         return value
 
+    def __str__(self):
+        return "SettingModuleProxy({0})".format(self.app_label)
+
     def get_setting(self, model_name):
         """
         Get a setting instance
         """
         Model = registry.get_by_natural_key(self.app_label, model_name)
         if Model is None:
-            return None
+            raise RuntimeError(
+                f"Could not find model matching `{self.app_label}.{model_name}`."
+            )
 
-        if isinstance(self.request_or_site, Site):
-            return Model.for_site(self.request_or_site)
-        # Utilises cached value on request if set
-        return Model.for_request(self.request_or_site)
+        if issubclass(Model, BaseGenericSetting):
+            return Model.load(request_or_site=self.request_or_site)
+        elif issubclass(Model, BaseSiteSetting):
+            if self.request_or_site is not None:
+                if isinstance(self.request_or_site, Site):
+                    return Model.for_site(self.request_or_site)
 
-    def __str__(self):
-        return "SettingsModuleProxy({0})".format(self.app_label)
+                # Utilises cached value on request if set
+                return Model.for_request(self.request_or_site)
+
+            raise RuntimeError(
+                "Site-specific settings cannot be identified because "
+                "`request` is not available in the context and "
+                "`use_default_site` is False."
+            )
+
+        raise NotImplementedError(
+            "Setting models should inherit from either `BaseGenericSetting` "
+            "or `BaseSiteSetting`."
+        )
 
 
 def settings(request):
-
-    # delay site query until settings values are needed
+    # Delay query until settings values are needed
     def _inner(request):
         site = Site.find_for_request(request)
         if site is None:
-            # find_for_request() can't determine the site,
-            # so no settings can be idenfified
-            return {}
-        else:
-            return SettingsProxy(request)
+            return SettingProxy(request_or_site=None)
+
+        return SettingProxy(request_or_site=request)
 
     return {"settings": SimpleLazyObject(lambda: _inner(request))}
