@@ -41,7 +41,7 @@ class Sitemap(DjangoSitemap):
         urls = []
         last_mods = set()
 
-        for item in self.paginator.page(page).object_list:
+        for item in self.paginator.page(page).object_list.iterator():
 
             url_info_items = item.get_sitemap_urls(self.request)
 
