@@ -1,7 +1,7 @@
 from django.test import TestCase
 from django.urls import reverse
 
-from wagtail.tests.utils import WagtailTestUtils
+from wagtail.test.utils import WagtailTestUtils
 
 
 class TestStyleGuide(TestCase, WagtailTestUtils):
@@ -9,7 +9,7 @@ class TestStyleGuide(TestCase, WagtailTestUtils):
         self.login()
 
     def test_styleguide(self):
-        response = self.client.get(reverse('wagtailstyleguide'))
+        response = self.client.get(reverse("wagtailstyleguide"))
 
         self.assertEqual(response.status_code, 200)
-        self.assertTemplateUsed(response, 'wagtailstyleguide/base.html')
+        self.assertTemplateUsed(response, "wagtailstyleguide/base.html")
