@@ -13,6 +13,7 @@ class ImageRenditionField(Field):
     Example:
     "thumbnail": {
         "url": "/media/images/myimage.max-165x165.jpg",
+        "full_url": "https://media.example.com/media/images/myimage.max-165x165.jpg",
         "width": 165,
         "height": 100,
         "alt": "Image alt text"
@@ -37,6 +38,7 @@ class ImageRenditionField(Field):
             return OrderedDict(
                 [
                     ("url", thumbnail.url),
+                    ("full_url", thumbnail.full_url),
                     ("width", thumbnail.width),
                     ("height", thumbnail.height),
                     ("alt", thumbnail.alt),
