@@ -25,7 +25,10 @@ from willow.image import Image as WillowImage
 from wagtail import hooks
 from wagtail.admin.models import get_object_usage
 from wagtail.coreutils import string_to_ascii
-from wagtail.images.exceptions import InvalidFilterSpecError
+from wagtail.images.exceptions import (
+    InvalidFilterSpecError,
+    UnknownOutputImageFormatError,
+)
 from wagtail.images.image_operations import (
     FilterOperation,
     ImageTransform,
@@ -56,7 +59,29 @@ class SourceImageIOError(IOError):
 
 
 class ImageQuerySet(SearchableQuerySetMixin, models.QuerySet):
-    pass
+    def prefetch_renditions(self, *filters):
+        """
+        Prefetches generated renditions for the given filters.
+        Returns all renditions when no filters are provided.
+        """
+        rendition_model = self.model.get_rendition_model()
+        queryset = rendition_model.objects.all()
+
+        if filters:
+            # Get a list of filter spec strings. The given value could contain Filter objects
+            filter_specs = [
+                filter.spec if isinstance(filter, Filter) else filter
+                for filter in filters
+            ]
+            queryset = queryset.filter(filter_spec__in=filter_specs)
+
+        return self.prefetch_related(
+            models.Prefetch(
+                "renditions",
+                queryset=queryset,
+                to_attr="prefetched_renditions",
+            )
+        )
 
 
 def get_upload_to(instance, filename):
@@ -211,6 +236,16 @@ class AbstractImage(ImageFileMixin, CollectionMember, index.Indexed, models.Mode
 
         return self.file_hash
 
+    def _set_image_file_metadata(self):
+        self.file.open()
+
+        # Set new image file size
+        self.file_size = self.file.size
+
+        # Set new image file hash
+        self._set_file_hash(self.file.read())
+        self.file.seek(0)
+
     def get_upload_to(self, filename):
         folder_name = "original_images"
         filename = self.file.field.storage.get_valid_name(filename)
@@ -351,6 +386,8 @@ class AbstractImage(ImageFileMixin, CollectionMember, index.Indexed, models.Mode
                 self._prefetched_objects_cache["renditions"]._result_cache.append(
                     rendition
                 )
+            elif hasattr(self, "prefetched_renditions"):
+                self.prefetched_renditions.append(rendition)
 
         try:
             cache = caches["renditions"]
@@ -381,7 +418,12 @@ class AbstractImage(ImageFileMixin, CollectionMember, index.Indexed, models.Mode
 
         # Interrogate prefetched values first (if available)
         if "renditions" in getattr(self, "_prefetched_objects_cache", {}):
-            for rendition in self.renditions.all():
+            prefetched_renditions = self.renditions.all()
+        else:
+            prefetched_renditions = getattr(self, "prefetched_renditions", None)
+
+        if prefetched_renditions is not None:
+            for rendition in prefetched_renditions:
                 if (
                     rendition.filter_spec == filter.spec
                     and rendition.focal_point_key == cache_key
@@ -418,7 +460,7 @@ class AbstractImage(ImageFileMixin, CollectionMember, index.Indexed, models.Mode
         Note: If using custom image models, an instance of the custom rendition
         model will be returned.
         """
-        # Because of unique contraints applied to the model, we use
+        # Because of unique constraints applied to the model, we use
         # get_or_create() to guard against race conditions
         rendition, created = self.renditions.get_or_create(
             filter_spec=filter.spec,
@@ -677,6 +719,9 @@ class Filter:
                     quality = getattr(settings, "WAGTAILIMAGES_WEBP_QUALITY", 85)
 
                 return willow.save_as_webp(output, quality=quality)
+            raise UnknownOutputImageFormatError(
+                f"Unknown output image format '{output_format}'"
+            )
 
     def get_cache_key(self, image):
         vary_parts = []
