@@ -9,22 +9,23 @@ from django.utils.encoding import force_str
 # Helper functions for migrating the Rendition.filter foreign key to the filter_spec field,
 # and the corresponding reverse migration
 def get_fill_filter_spec_migrations(app_name, rendition_model_name):
-
     def fill_filter_spec_forward(apps, schema_editor):
         # Populate Rendition.filter_spec with the spec string of the corresponding Filter object
         Rendition = apps.get_model(app_name, rendition_model_name)
-        Filter = apps.get_model('wagtailimages', 'Filter')
+        Filter = apps.get_model("wagtailimages", "Filter")
 
         db_alias = schema_editor.connection.alias
         for flt in Filter.objects.using(db_alias):
-            renditions = Rendition.objects.using(db_alias).filter(filter=flt, filter_spec='')
+            renditions = Rendition.objects.using(db_alias).filter(
+                filter=flt, filter_spec=""
+            )
             renditions.update(filter_spec=flt.spec)
 
     def fill_filter_spec_reverse(apps, schema_editor):
         # Populate the Rendition.filter field with Filter objects that match the spec in the
         # Rendition's filter_spec field
         Rendition = apps.get_model(app_name, rendition_model_name)
-        Filter = apps.get_model('wagtailimages', 'Filter')
+        Filter = apps.get_model("wagtailimages", "Filter")
         db_alias = schema_editor.connection.alias
 
         while True:
@@ -33,14 +34,22 @@ def get_fill_filter_spec_migrations(app_name, rendition_model_name):
             # by active server processes while the query is in progress
 
             # Find all distinct filter_spec strings used by renditions with a null 'filter' field
-            unmatched_filter_specs = Rendition.objects.using(db_alias).filter(
-                filter__isnull=True).values_list('filter_spec', flat=True).distinct()
+            unmatched_filter_specs = (
+                Rendition.objects.using(db_alias)
+                .filter(filter__isnull=True)
+                .values_list("filter_spec", flat=True)
+                .distinct()
+            )
             if not unmatched_filter_specs:
                 break
 
             for filter_spec in unmatched_filter_specs:
-                filter, _ = Filter.objects.using(db_alias).get_or_create(spec=filter_spec)
-                Rendition.objects.using(db_alias).filter(filter_spec=filter_spec).update(filter=filter)
+                filter, _ = Filter.objects.using(db_alias).get_or_create(
+                    spec=filter_spec
+                )
+                Rendition.objects.using(db_alias).filter(
+                    filter_spec=filter_spec
+                ).update(filter=filter)
 
     return (fill_filter_spec_forward, fill_filter_spec_reverse)
 
@@ -63,7 +72,7 @@ def parse_color_string(color_string):
         g = int(color_string[2:4], 16)
         b = int(color_string[4:6], 16)
     else:
-        raise ValueError('Color string must be either 3 or 6 hexadecimal digits long')
+        raise ValueError("Color string must be either 3 or 6 hexadecimal digits long")
 
     return r, g, b
 
@@ -78,9 +87,22 @@ def generate_signature(image_id, filter_spec, key=None):
 
     # Based on libthumbor hmac generation
     # https://github.com/thumbor/libthumbor/blob/b19dc58cf84787e08c8e397ab322e86268bb4345/libthumbor/crypto.py#L50
-    url = '{}/{}/'.format(image_id, filter_spec)
-    return force_str(base64.urlsafe_b64encode(hmac.new(key, url.encode(), hashlib.sha1).digest()))
+    url = "{}/{}/".format(image_id, filter_spec)
+    return force_str(
+        base64.urlsafe_b64encode(hmac.new(key, url.encode(), hashlib.sha1).digest())
+    )
 
 
 def verify_signature(signature, image_id, filter_spec, key=None):
     return force_str(signature) == generate_signature(image_id, filter_spec, key=key)
+
+
+def find_image_duplicates(image, user, permission_policy):
+    """
+    Finds all the duplicates of a given image.
+    To keep things simple, two images are considered to be duplicates if they have the same `file_hash` value.
+    This function also ensures that the `user` can choose one of the duplicate images returned (if any).
+    """
+
+    instances = permission_policy.instances_user_has_permission_for(user, "choose")
+    return instances.exclude(pk=image.pk).filter(file_hash=image.file_hash)
