@@ -25,31 +25,77 @@ from wagtail.images.models import Filter, SourceImageIOError
 from wagtail.images.permissions import permission_policy
 from wagtail.images.utils import generate_signature
 from wagtail.models import Collection, Site
-from wagtail.search import index as search_index
 
 permission_checker = PermissionPolicyChecker(permission_policy)
 
-INDEX_PAGE_SIZE = getattr(settings, "WAGTAILIMAGES_INDEX_PAGE_SIZE", 20)
+INDEX_PAGE_SIZE = getattr(settings, "WAGTAILIMAGES_INDEX_PAGE_SIZE", 30)
 USAGE_PAGE_SIZE = getattr(settings, "WAGTAILIMAGES_USAGE_PAGE_SIZE", 20)
 
 
 class BaseListingView(TemplateView):
+    ENTRIES_PER_PAGE_CHOICES = sorted({10, 30, 60, 100, 250, INDEX_PAGE_SIZE})
+    ORDERING_OPTIONS = {
+        "-created_at": _("Newest"),
+        "created_at": _("Oldest"),
+        "title": _("Title: (A -> Z)"),
+        "-title": _("Title: (Z -> A)"),
+        "file_size": _("File size: (low to high)"),
+        "-file_size": _("File size: (high to low)"),
+    }
+    default_ordering = "-created_at"
+
     @method_decorator(permission_checker.require_any("add", "change", "delete"))
     def get(self, request):
         return super().get(request)
 
+    def get_num_entries_per_page(self):
+        entries_per_page = self.request.GET.get("entries_per_page", INDEX_PAGE_SIZE)
+        try:
+            entries_per_page = int(entries_per_page)
+        except ValueError:
+            entries_per_page = INDEX_PAGE_SIZE
+        if entries_per_page not in self.ENTRIES_PER_PAGE_CHOICES:
+            entries_per_page = INDEX_PAGE_SIZE
+
+        return entries_per_page
+
+    def get_valid_orderings(self):
+        return self.ORDERING_OPTIONS
+
+    def get_ordering(self):
+        # TODO: remove this method when this view will be based on the
+        # generic model index view from wagtail.admin.views.generic.models.IndexView
+        ordering = self.request.GET.get("ordering")
+        if ordering is None or ordering not in self.get_valid_orderings():
+            ordering = self.default_ordering
+        return ordering
+
     def get_context_data(self, **kwargs):
         context = super().get_context_data(**kwargs)
 
-        # Get images (filtered by user permission)
+        # Get ordering
+        ordering = self.get_ordering()
+
+        # Get images (filtered by user permission and ordered by `ordering`)
         images = (
             permission_policy.instances_user_has_any_permission_for(
                 self.request.user, ["change", "delete"]
             )
-            .order_by("-created_at")
+            .order_by(ordering)
             .select_related("collection")
+            .prefetch_renditions("max-165x165")
         )
 
+        # Filter by collection
+        self.current_collection = None
+        collection_id = self.request.GET.get("collection_id")
+        if collection_id:
+            try:
+                self.current_collection = Collection.objects.get(id=collection_id)
+                images = images.filter(collection=self.current_collection)
+            except (ValueError, Collection.DoesNotExist):
+                pass
+
         # Search
         query_string = None
         if "q" in self.request.GET:
@@ -61,16 +107,6 @@ class BaseListingView(TemplateView):
         else:
             self.form = SearchForm(placeholder=_("Search images"))
 
-        # Filter by collection
-        self.current_collection = None
-        collection_id = self.request.GET.get("collection_id")
-        if collection_id:
-            try:
-                self.current_collection = Collection.objects.get(id=collection_id)
-                images = images.filter(collection=self.current_collection)
-            except (ValueError, Collection.DoesNotExist):
-                pass
-
         # Filter by tag
         self.current_tag = self.request.GET.get("tag")
         if self.current_tag:
@@ -79,7 +115,8 @@ class BaseListingView(TemplateView):
             except (AttributeError):
                 self.current_tag = None
 
-        paginator = Paginator(images, per_page=INDEX_PAGE_SIZE)
+        entries_per_page = self.get_num_entries_per_page()
+        paginator = Paginator(images, per_page=entries_per_page)
         images = paginator.get_page(self.request.GET.get("p"))
 
         next_url = reverse("wagtailimages:index")
@@ -93,6 +130,10 @@ class BaseListingView(TemplateView):
                 "query_string": query_string,
                 "is_searching": bool(query_string),
                 "next": next_url,
+                "entries_per_page": entries_per_page,
+                "ENTRIES_PER_PAGE_CHOICES": self.ENTRIES_PER_PAGE_CHOICES,
+                "current_ordering": ordering,
+                "ORDERING_OPTIONS": self.ORDERING_OPTIONS,
             }
         )
 
@@ -149,30 +190,10 @@ def edit(request, image_id):
     next_url = get_valid_next_url_from_request(request)
 
     if request.method == "POST":
-        original_file = image.file
         form = ImageForm(request.POST, request.FILES, instance=image, user=request.user)
         if form.is_valid():
-            if "file" in form.changed_data:
-                # Set new image file size
-                image.file_size = image.file.size
-
-                # Set new image file hash
-                image.file.seek(0)
-                image._set_file_hash(image.file.read())
-                image.file.seek(0)
-
             form.save()
 
-            if "file" in form.changed_data:
-                # if providing a new image file, delete the old one and all renditions.
-                # NB Doing this via original_file.delete() clears the file field,
-                # which definitely isn't what we want...
-                original_file.storage.delete(original_file.name)
-                image.renditions.all().delete()
-
-            # Reindex the image to make sure all tags are indexed
-            search_index.insert_or_update_object(image)
-
             edit_url = reverse("wagtailimages:edit", args=(image.id,))
             redirect_url = "wagtailimages:index"
             if next_url:
@@ -349,19 +370,8 @@ def add(request):
         image = ImageModel(uploaded_by_user=request.user)
         form = ImageForm(request.POST, request.FILES, instance=image, user=request.user)
         if form.is_valid():
-            # Set image file size
-            image.file_size = image.file.size
-
-            # Set image file hash
-            image.file.seek(0)
-            image._set_file_hash(image.file.read())
-            image.file.seek(0)
-
             form.save()
 
-            # Reindex the image to make sure all tags are indexed
-            search_index.insert_or_update_object(image)
-
             messages.success(
                 request,
                 _("Image '{0}' added.").format(image.title),
