@@ -7,7 +7,6 @@ from django.db import transaction
 from wagtail.search.backends import get_search_backend
 from wagtail.search.index import get_indexed_models
 
-
 DEFAULT_CHUNK_SIZE = 1000
 
 
@@ -46,14 +45,18 @@ def group_models_by_index(backend, models):
             models_by_index.setdefault(index.name, [])
             models_by_index[index.name].append(model)
 
-    return collections.OrderedDict([
-        (indices[index_name], index_models)
-        for index_name, index_models in models_by_index.items()
-    ])
+    return collections.OrderedDict(
+        [
+            (indices[index_name], index_models)
+            for index_name, index_models in models_by_index.items()
+        ]
+    )
 
 
 class Command(BaseCommand):
-    def update_backend(self, backend_name, schema_only=False, chunk_size=DEFAULT_CHUNK_SIZE):
+    def update_backend(
+        self, backend_name, schema_only=False, chunk_size=DEFAULT_CHUNK_SIZE
+    ):
         self.stdout.write("Updating backend: " + backend_name)
 
         backend = get_search_backend(backend_name)
@@ -62,7 +65,9 @@ class Command(BaseCommand):
             self.stdout.write("Backend '%s' doesn't require rebuilding" % backend_name)
             return
 
-        models_grouped_by_index = group_models_by_index(backend, get_indexed_models()).items()
+        models_grouped_by_index = group_models_by_index(
+            backend, get_indexed_models()
+        ).items()
         if not models_grouped_by_index:
             self.stdout.write(backend_name + ": No indices to rebuild")
 
@@ -81,10 +86,19 @@ class Command(BaseCommand):
             object_count = 0
             if not schema_only:
                 for model in models:
-                    self.stdout.write('{}: {}.{} '.format(backend_name, model._meta.app_label, model.__name__).ljust(35), ending='')
+                    self.stdout.write(
+                        "{}: {}.{} ".format(
+                            backend_name, model._meta.app_label, model.__name__
+                        ).ljust(35),
+                        ending="",
+                    )
 
                     # Add items (chunk_size at a time)
-                    for chunk in self.print_iter_progress(self.queryset_chunks(model.get_indexed_objects().order_by('pk'), chunk_size)):
+                    for chunk in self.print_iter_progress(
+                        self.queryset_chunks(
+                            model.get_indexed_objects().order_by("pk"), chunk_size
+                        )
+                    ):
                         index.add_items(model, chunk)
                         object_count += len(chunk)
 
@@ -98,36 +112,50 @@ class Command(BaseCommand):
 
     def add_arguments(self, parser):
         parser.add_argument(
-            '--backend', action='store', dest='backend_name', default=None,
-            help="Specify a backend to update")
+            "--backend",
+            action="store",
+            dest="backend_name",
+            default=None,
+            help="Specify a backend to update",
+        )
         parser.add_argument(
-            '--schema-only', action='store_true', dest='schema_only', default=False,
-            help="Prevents loading any data into the index")
+            "--schema-only",
+            action="store_true",
+            dest="schema_only",
+            default=False,
+            help="Prevents loading any data into the index",
+        )
         parser.add_argument(
-            '--chunk_size', action='store', dest='chunk_size', default=DEFAULT_CHUNK_SIZE, type=int,
-            help="Set number of records to be fetched at once for inserting into the index")
+            "--chunk_size",
+            action="store",
+            dest="chunk_size",
+            default=DEFAULT_CHUNK_SIZE,
+            type=int,
+            help="Set number of records to be fetched at once for inserting into the index",
+        )
 
     def handle(self, **options):
         # Get list of backends to index
-        if options['backend_name']:
+        if options["backend_name"]:
             # index only the passed backend
-            backend_names = [options['backend_name']]
-        elif hasattr(settings, 'WAGTAILSEARCH_BACKENDS'):
+            backend_names = [options["backend_name"]]
+        elif hasattr(settings, "WAGTAILSEARCH_BACKENDS"):
             # index all backends listed in settings
             backend_names = settings.WAGTAILSEARCH_BACKENDS.keys()
         else:
             # index the 'default' backend only
-            backend_names = ['default']
+            backend_names = ["default"]
 
         # Update backends
         for backend_name in backend_names:
             self.update_backend(
                 backend_name,
-                schema_only=options.get('schema_only', False), chunk_size=options.get('chunk_size')
+                schema_only=options.get("schema_only", False),
+                chunk_size=options.get("chunk_size"),
             )
 
     def print_newline(self):
-        self.stdout.write('')
+        self.stdout.write("")
 
     def print_iter_progress(self, iterable):
         """
@@ -142,17 +170,17 @@ class Command(BaseCommand):
         """
         for i, value in enumerate(iterable, start=1):
             yield value
-            self.stdout.write('.', ending='')
+            self.stdout.write(".", ending="")
             if i % 40 == 0:
                 self.print_newline()
-                self.stdout.write(' ' * 35, ending='')
+                self.stdout.write(" " * 35, ending="")
 
             elif i % 10 == 0:
-                self.stdout.write(' ', ending='')
+                self.stdout.write(" ", ending="")
 
             self.stdout.flush()
 
-    # Atomic so the count of models doesnt change as it is iterated
+    # Atomic so the count of models doesn't change as it is iterated
     @transaction.atomic
     def queryset_chunks(self, qs, chunk_size=DEFAULT_CHUNK_SIZE):
         """
@@ -163,7 +191,7 @@ class Command(BaseCommand):
         """
         i = 0
         while True:
-            items = list(qs[i * chunk_size:][:chunk_size])
+            items = list(qs[i * chunk_size :][:chunk_size])
             if not items:
                 break
             yield items
