@@ -11,7 +11,7 @@ from django.core.paginator import EmptyPage, PageNotAnInteger, Paginator
 from django.db import models
 from django.shortcuts import redirect
 from django.template.response import TemplateResponse
-from django.utils.functional import lazystr
+from django.utils.translation import gettext_lazy as _
 from modelcluster.contrib.taggit import ClusterTaggableManager
 from modelcluster.fields import ParentalKey, ParentalManyToManyField
 from modelcluster.models import ClusterableModel
@@ -44,7 +44,11 @@ from wagtail.contrib.forms.models import (
     AbstractFormSubmission,
 )
 from wagtail.contrib.forms.views import SubmissionsListView
-from wagtail.contrib.settings.models import BaseSetting, register_setting
+from wagtail.contrib.settings.models import (
+    BaseGenericSetting,
+    BaseSiteSetting,
+    register_setting,
+)
 from wagtail.contrib.sitemaps import Sitemap
 from wagtail.contrib.table_block.blocks import TableBlock
 from wagtail.documents import get_document_model
@@ -54,10 +58,13 @@ from wagtail.images import get_image_model
 from wagtail.images.blocks import ImageChooserBlock
 from wagtail.images.models import AbstractImage, AbstractRendition, Image
 from wagtail.models import (
+    DraftStateMixin,
     Orderable,
     Page,
     PageManager,
     PageQuerySet,
+    PreviewableMixin,
+    RevisionMixin,
     Task,
     TranslatableMixin,
 )
@@ -165,7 +172,7 @@ class SimplePage(Page):
     page_description = "A simple page description"
 
     content_panels = [
-        FieldPanel("title", classname="full title"),
+        FieldPanel("title", classname="title"),
         FieldPanel("content"),
     ]
 
@@ -173,6 +180,23 @@ class SimplePage(Page):
         return "%s (simple page)" % super().get_admin_display_title()
 
 
+class MultiPreviewModesPage(Page):
+    template = "tests/simple_page.html"
+
+    @property
+    def preview_modes(self):
+        return [("original", "Original"), ("alt#1", "Alternate")]
+
+    @property
+    def default_preview_mode(self):
+        return "alt#1"
+
+    def get_preview_template(self, request, mode_name):
+        if mode_name == "alt#1":
+            return "tests/simple_page_alt.html"
+        return super().get_preview_template(request, mode_name)
+
+
 # Page with Excluded Fields when copied
 class PageWithExcludedCopyField(Page):
     content = models.TextField()
@@ -182,7 +206,7 @@ class PageWithExcludedCopyField(Page):
     exclude_fields_in_copy = ["special_field"]
 
     content_panels = [
-        FieldPanel("title", classname="full title"),
+        FieldPanel("title", classname="title"),
         FieldPanel("special_field"),
         FieldPanel("content"),
     ]
@@ -217,7 +241,7 @@ class FilePage(Page):
     file_field = models.FileField()
 
     content_panels = [
-        FieldPanel("title", classname="full title"),
+        FieldPanel("title", classname="title"),
         HelpPanel("remember to check for viruses"),
         FieldPanel("file_field"),
     ]
@@ -352,18 +376,23 @@ class EventPage(Page):
     base_form_class = EventPageForm
 
     content_panels = [
-        FieldPanel("title", classname="full title"),
+        FieldPanel("title", classname="title"),
         FieldPanel("date_from"),
         FieldPanel("date_to"),
         FieldPanel("time_from"),
         FieldPanel("time_to"),
         FieldPanel("location"),
-        FieldPanel("audience"),
+        FieldPanel("audience", help_text="Who this event is for"),
         FieldPanel("cost"),
         FieldPanel("signup_link"),
         InlinePanel("carousel_items", label="Carousel items"),
-        FieldPanel("body", classname="full"),
-        InlinePanel("speakers", label="Speakers", heading="Speaker lineup"),
+        FieldPanel("body"),
+        InlinePanel(
+            "speakers",
+            label="Speakers",
+            heading="Speaker lineup",
+            help_text="Put the keynote speaker first",
+        ),
         InlinePanel("related_links", label="Related links"),
         FieldPanel("categories"),
         # InlinePanel related model uses `pk` not `id`
@@ -371,7 +400,9 @@ class EventPage(Page):
     ]
 
     promote_panels = [
-        MultiFieldPanel(COMMON_PANELS, "Common page configuration"),
+        MultiFieldPanel(
+            COMMON_PANELS, "Common page configuration", help_text="For SEO nerds only"
+        ),
         FieldPanel("feed_image"),
     ]
 
@@ -394,7 +425,7 @@ class FormClassAdditionalFieldPage(Page):
     body = RichTextField(blank=True)
 
     content_panels = [
-        FieldPanel("title", classname="full title"),
+        FieldPanel("title", classname="title"),
         FieldPanel("location"),
         FieldPanel("body"),
         FieldPanel("code"),  # not in model, see set base_form_class
@@ -442,7 +473,7 @@ class EventSitemap(Sitemap):
 
 # Event index (has a separate AJAX template, and a custom template context)
 class EventIndex(Page):
-    intro = RichTextField(blank=True)
+    intro = RichTextField(blank=True, max_length=50)
     ajax_template = "tests/includes/event_listing.html"
 
     def get_events(self):
@@ -500,8 +531,8 @@ class EventIndex(Page):
         return super().get_cached_paths() + ["/past/"]
 
     content_panels = [
-        FieldPanel("title", classname="full title"),
-        FieldPanel("intro", classname="full"),
+        FieldPanel("title", classname="title"),
+        FieldPanel("intro"),
     ]
 
 
@@ -523,13 +554,13 @@ class FormPage(AbstractEmailForm):
     submissions_list_view_class = SubmissionsListView
 
     content_panels = [
-        FieldPanel("title", classname="full title"),
+        FieldPanel("title", classname="title"),
         InlinePanel("form_fields", label="Form fields"),
         MultiFieldPanel(
             [
-                FieldPanel("to_address", classname="full"),
-                FieldPanel("from_address", classname="full"),
-                FieldPanel("subject", classname="full"),
+                FieldPanel("to_address"),
+                FieldPanel("from_address"),
+                FieldPanel("subject"),
             ],
             "Email",
         ),
@@ -549,13 +580,13 @@ class JadeFormPage(AbstractEmailForm):
     template = "tests/form_page.jade"
 
     content_panels = [
-        FieldPanel("title", classname="full title"),
+        FieldPanel("title", classname="title"),
         InlinePanel("form_fields", label="Form fields"),
         MultiFieldPanel(
             [
-                FieldPanel("to_address", classname="full"),
-                FieldPanel("from_address", classname="full"),
-                FieldPanel("subject", classname="full"),
+                FieldPanel("to_address"),
+                FieldPanel("from_address"),
+                FieldPanel("subject"),
             ],
             "Email",
         ),
@@ -597,14 +628,14 @@ class FormPageWithRedirect(AbstractEmailForm):
         )
 
     content_panels = [
-        FieldPanel("title", classname="full title"),
+        FieldPanel("title", classname="title"),
         FieldPanel("thank_you_redirect_page"),
         InlinePanel("form_fields", label="Form fields"),
         MultiFieldPanel(
             [
-                FieldPanel("to_address", classname="full"),
-                FieldPanel("from_address", classname="full"),
-                FieldPanel("subject", classname="full"),
+                FieldPanel("to_address"),
+                FieldPanel("from_address"),
+                FieldPanel("subject"),
             ],
             "Email",
         ),
@@ -681,15 +712,15 @@ class FormPageWithCustomSubmission(AbstractEmailForm):
         return super().serve(request, *args, **kwargs)
 
     content_panels = [
-        FieldPanel("title", classname="full title"),
-        FieldPanel("intro", classname="full"),
+        FieldPanel("title", classname="title"),
+        FieldPanel("intro"),
         InlinePanel("custom_form_fields", label="Form fields"),
-        FieldPanel("thank_you_text", classname="full"),
+        FieldPanel("thank_you_text"),
         MultiFieldPanel(
             [
-                FieldPanel("to_address", classname="full"),
-                FieldPanel("from_address", classname="full"),
-                FieldPanel("subject", classname="full"),
+                FieldPanel("to_address"),
+                FieldPanel("from_address"),
+                FieldPanel("subject"),
             ],
             "Email",
         ),
@@ -752,15 +783,15 @@ class FormPageWithCustomSubmissionListView(AbstractEmailForm):
         return data_fields
 
     content_panels = [
-        FieldPanel("title", classname="full title"),
-        FieldPanel("intro", classname="full"),
+        FieldPanel("title", classname="title"),
+        FieldPanel("intro"),
         InlinePanel("form_fields", label="Form fields"),
-        FieldPanel("thank_you_text", classname="full"),
+        FieldPanel("thank_you_text"),
         MultiFieldPanel(
             [
-                FieldPanel("to_address", classname="full"),
-                FieldPanel("from_address", classname="full"),
-                FieldPanel("subject", classname="full"),
+                FieldPanel("to_address"),
+                FieldPanel("from_address"),
+                FieldPanel("subject"),
             ],
             "Email",
         ),
@@ -773,7 +804,10 @@ EXTENDED_CHOICES = FORM_FIELD_CHOICES + (("ipaddress", "IP Address"),)
 
 
 class ExtendedFormField(AbstractFormField):
-    """Override the field_type field with extended choices."""
+    """
+    Override the field_type field with extended choices
+    and a custom clean_name override.
+    """
 
     page = ParentalKey(
         "FormPageWithCustomFormBuilder",
@@ -784,6 +818,19 @@ class ExtendedFormField(AbstractFormField):
         verbose_name="field type", max_length=16, choices=EXTENDED_CHOICES
     )
 
+    def get_field_clean_name(self):
+        clean_name = super().get_field_clean_name()
+
+        # scoping to field type to easily test behaviour in isolation
+        if self.field_type == "number":
+            return f"number_field--{clean_name}"
+
+        # scoping to field label to easily test duplicate behaviour in isolation
+        if "duplicate" in self.label:
+            return "test duplicate"
+
+        return clean_name
+
 
 class CustomFormBuilder(FormBuilder):
     """
@@ -808,13 +855,13 @@ class FormPageWithCustomFormBuilder(AbstractEmailForm):
     form_builder = CustomFormBuilder
 
     content_panels = [
-        FieldPanel("title", classname="full title"),
+        FieldPanel("title", classname="title"),
         InlinePanel("form_fields", label="Form fields"),
         MultiFieldPanel(
             [
-                FieldPanel("to_address", classname="full"),
-                FieldPanel("from_address", classname="full"),
-                FieldPanel("subject", classname="full"),
+                FieldPanel("to_address"),
+                FieldPanel("from_address"),
+                FieldPanel("subject"),
             ],
             "Email",
         ),
@@ -908,8 +955,11 @@ class AdvertWithTabbedInterface(models.Model):
     edit_handler = TabbedInterface(
         [
             ObjectList(advert_panels, heading="Advert"),
-            ObjectList(other_panels, heading="Other"),
-        ]
+            ObjectList(
+                other_panels, heading="Other", help_text="Other panels help text"
+            ),
+        ],
+        help_text="Top-level help text",
     )
 
     def __str__(self):
@@ -922,6 +972,112 @@ class AdvertWithTabbedInterface(models.Model):
 register_snippet(AdvertWithTabbedInterface)
 
 
+# Models with RevisionMixin
+class RevisableModel(RevisionMixin, models.Model):
+    text = models.TextField()
+
+
+register_snippet(RevisableModel)
+
+
+class RevisableChildModel(RevisableModel):
+    secret_text = models.TextField(blank=True, default="")
+
+    panels = [
+        FieldPanel("text"),
+        FieldPanel("secret_text", permission="superuser"),
+    ]
+
+
+register_snippet(RevisableChildModel)
+
+
+class RevisableGrandChildModel(RevisableChildModel):
+    pass
+
+
+# Models with DraftStateMixin
+class DraftStateModel(DraftStateMixin, RevisionMixin, models.Model):
+    text = models.TextField()
+
+    panels = [
+        FieldPanel("text"),
+    ]
+
+    def __str__(self):
+        return self.text
+
+
+register_snippet(DraftStateModel)
+
+
+class DraftStateCustomPrimaryKeyModel(DraftStateMixin, RevisionMixin, models.Model):
+    custom_id = models.CharField(max_length=255, primary_key=True)
+    text = models.TextField()
+
+    panels = [
+        FieldPanel("text"),
+    ]
+
+    def __str__(self):
+        return self.text
+
+
+register_snippet(DraftStateCustomPrimaryKeyModel)
+
+
+# Models with PreviewableMixin
+class PreviewableModel(PreviewableMixin, ClusterableModel):
+    text = models.TextField()
+    categories = ParentalManyToManyField(EventCategory, blank=True)
+
+    def __str__(self):
+        return self.text
+
+    def get_preview_template(self, request, mode_name):
+        return "tests/previewable_model.html"
+
+
+register_snippet(PreviewableModel)
+
+
+class MultiPreviewModesModel(PreviewableMixin, RevisionMixin, models.Model):
+    text = models.TextField()
+
+    def __str__(self):
+        return self.text
+
+    @property
+    def preview_modes(self):
+        return [("", "Normal"), ("alt#1", "Alternate")]
+
+    @property
+    def default_preview_mode(self):
+        return "alt#1"
+
+    def get_preview_template(self, request, mode_name):
+        templates = {
+            "": "tests/previewable_model.html",
+            "alt#1": "tests/previewable_model_alt.html",
+        }
+        return templates.get(mode_name, templates[""])
+
+
+register_snippet(MultiPreviewModesModel)
+
+
+class NonPreviewableModel(PreviewableMixin, RevisionMixin, models.Model):
+    text = models.TextField()
+
+    def __str__(self):
+        return self.text
+
+    preview_modes = []
+
+
+register_snippet(NonPreviewableModel)
+
+
 class StandardIndex(Page):
     """Index for the site"""
 
@@ -930,7 +1086,7 @@ class StandardIndex(Page):
     # A custom panel setup where all Promote fields are placed in the Content tab instead;
     # we use this to test that the 'promote' tab is left out of the output when empty
     content_panels = [
-        FieldPanel("title", classname="full title"),
+        FieldPanel("title", classname="title"),
         FieldPanel("seo_title"),
         FieldPanel("slug"),
         InlinePanel("advert_placements", label="Adverts"),
@@ -948,12 +1104,10 @@ StandardChild.edit_handler = TabbedInterface(
     [
         ObjectList(StandardChild.content_panels, heading="Content"),
         ObjectList(StandardChild.promote_panels, heading="Promote"),
-        ObjectList(
-            StandardChild.settings_panels, heading="Settings", classname="settings"
-        ),
+        ObjectList(StandardChild.settings_panels, heading="Settings"),
         ObjectList(
             [
-                HelpPanel("remember to check for asteroids"),
+                HelpPanel("Watch out for asteroids"),
             ],
             heading="Dinosaurs",
         ),
@@ -982,7 +1136,7 @@ class BusinessChild(Page):
 
     subpage_types = []
     parent_page_types = ["tests.BusinessIndex", BusinessSubIndex]
-    page_description = lazystr("A lazy business child page description")
+    page_description = _("A lazy business child page description")
 
 
 class BusinessNowherePage(Page):
@@ -1001,7 +1155,7 @@ class TaggedPage(Page):
     tags = ClusterTaggableManager(through=TaggedPageTag, blank=True)
 
     content_panels = [
-        FieldPanel("title", classname="full title"),
+        FieldPanel("title", classname="title"),
         FieldPanel("tags"),
     ]
 
@@ -1285,13 +1439,32 @@ class AbstractPage(Page):
 
 
 @register_setting
-class TestSetting(BaseSetting):
+class TestSiteSetting(BaseSiteSetting):
     title = models.CharField(max_length=100)
     email = models.EmailField(max_length=50)
 
 
 @register_setting
-class ImportantPages(BaseSetting):
+class TestGenericSetting(BaseGenericSetting):
+    title = models.CharField(max_length=100)
+    email = models.EmailField(max_length=50)
+
+
+@register_setting
+class ImportantPagesSiteSetting(BaseSiteSetting):
+    sign_up_page = models.ForeignKey(
+        "wagtailcore.Page", related_name="+", null=True, on_delete=models.SET_NULL
+    )
+    general_terms_page = models.ForeignKey(
+        "wagtailcore.Page", related_name="+", null=True, on_delete=models.SET_NULL
+    )
+    privacy_policy_page = models.ForeignKey(
+        "wagtailcore.Page", related_name="+", null=True, on_delete=models.SET_NULL
+    )
+
+
+@register_setting
+class ImportantPagesGenericSetting(BaseGenericSetting):
     sign_up_page = models.ForeignKey(
         "wagtailcore.Page", related_name="+", null=True, on_delete=models.SET_NULL
     )
@@ -1304,16 +1477,30 @@ class ImportantPages(BaseSetting):
 
 
 @register_setting(icon="icon-setting-tag")
-class IconSetting(BaseSetting):
+class IconSiteSetting(BaseSiteSetting):
     pass
 
 
-class NotYetRegisteredSetting(BaseSetting):
+@register_setting(icon="icon-setting-tag")
+class IconGenericSetting(BaseGenericSetting):
+    pass
+
+
+class NotYetRegisteredSiteSetting(BaseSiteSetting):
+    pass
+
+
+class NotYetRegisteredGenericSetting(BaseGenericSetting):
     pass
 
 
 @register_setting
-class FileUploadSetting(BaseSetting):
+class FileSiteSetting(BaseSiteSetting):
+    file = models.FileField()
+
+
+@register_setting
+class FileGenericSetting(BaseGenericSetting):
     file = models.FileField()
 
 
@@ -1449,7 +1636,7 @@ class DefaultRichTextFieldPage(Page):
     body = RichTextField()
 
     content_panels = [
-        FieldPanel("title", classname="full title"),
+        FieldPanel("title", classname="title"),
         FieldPanel("body"),
     ]
 
@@ -1469,7 +1656,7 @@ class CustomRichTextFieldPage(Page):
     body = RichTextField(editor="custom")
 
     content_panels = [
-        FieldPanel("title", classname="full title"),
+        FieldPanel("title", classname="title"),
         FieldPanel("body"),
     ]
 
@@ -1483,7 +1670,7 @@ class CustomRichBlockFieldPage(Page):
     )
 
     content_panels = [
-        FieldPanel("title", classname="full title"),
+        FieldPanel("title", classname="title"),
         FieldPanel("body"),
     ]
 
@@ -1492,7 +1679,7 @@ class RichTextFieldWithFeaturesPage(Page):
     body = RichTextField(features=["quotation", "embed", "made-up-feature"])
 
     content_panels = [
-        FieldPanel("title", classname="full title"),
+        FieldPanel("title", classname="title"),
         FieldPanel("body"),
     ]
 
@@ -1510,7 +1697,7 @@ class SectionedRichTextPageSection(Orderable):
 
 class SectionedRichTextPage(Page):
     content_panels = [
-        FieldPanel("title", classname="full title"),
+        FieldPanel("title", classname="title"),
         InlinePanel("sections"),
     ]
 
@@ -1532,7 +1719,7 @@ class InlineStreamPageSection(Orderable):
 
 class InlineStreamPage(Page):
     content_panels = [
-        FieldPanel("title", classname="full title"),
+        FieldPanel("title", classname="title"),
         InlinePanel("sections"),
     ]
 
@@ -1549,11 +1736,24 @@ class UserProfile(models.Model):
     favourite_colour = models.CharField(max_length=255)
 
 
-class PanelSettings(TestSetting):
+class PanelSiteSettings(TestSiteSetting):
     panels = [FieldPanel("title")]
 
 
-class TabbedSettings(TestSetting):
+class PanelGenericSettings(TestGenericSetting):
+    panels = [FieldPanel("title")]
+
+
+class TabbedSiteSettings(TestSiteSetting):
+    edit_handler = TabbedInterface(
+        [
+            ObjectList([FieldPanel("title")], heading="First tab"),
+            ObjectList([FieldPanel("email")], heading="Second tab"),
+        ]
+    )
+
+
+class TabbedGenericSettings(TestGenericSetting):
     edit_handler = TabbedInterface(
         [
             ObjectList([FieldPanel("title")], heading="First tab"),
@@ -1590,13 +1790,11 @@ class SecretPage(Page):
 
 
 class SimpleParentPage(Page):
-    # `BusinessIndex` has been added to bring it in line with other tests
-    subpage_types = ["tests.SimpleChildPage", BusinessIndex]
+    subpage_types = ["tests.SimpleChildPage"]
 
 
 class SimpleChildPage(Page):
-    # `Page` has been added to bring it in line with other tests
-    parent_page_types = ["tests.SimpleParentPage", Page]
+    parent_page_types = ["tests.SimpleParentPage"]
 
     max_count_per_parent = 1
 
@@ -1717,3 +1915,44 @@ class DeadlyStreamPage(Page):
 # (so that it's possible to use them in foreign key definitions, for example)
 ReimportedImageModel = get_image_model()
 ReimportedDocumentModel = get_document_model()
+
+
+# Custom document model with a custom tag field
+class TaggedRestaurantDocument(ItemBase):
+    tag = models.ForeignKey(
+        RestaurantTag, related_name="tagged_documents", on_delete=models.CASCADE
+    )
+    content_object = models.ForeignKey(
+        to="tests.CustomRestaurantDocument",
+        on_delete=models.CASCADE,
+        related_name="tagged_items",
+    )
+
+
+class CustomRestaurantDocument(AbstractDocument):
+    tags = TaggableManager(
+        help_text=None,
+        blank=True,
+        verbose_name="tags",
+        through=TaggedRestaurantDocument,
+    )
+    admin_form_fields = Document.admin_form_fields
+
+
+# Custom image model with a custom tag field
+class TaggedRestaurantImage(ItemBase):
+    tag = models.ForeignKey(
+        RestaurantTag, related_name="tagged_images", on_delete=models.CASCADE
+    )
+    content_object = models.ForeignKey(
+        to="tests.CustomRestaurantImage",
+        on_delete=models.CASCADE,
+        related_name="tagged_items",
+    )
+
+
+class CustomRestaurantImage(AbstractImage):
+    tags = TaggableManager(
+        help_text=None, blank=True, verbose_name="tags", through=TaggedRestaurantImage
+    )
+    admin_form_fields = Image.admin_form_fields
