@@ -9,7 +9,7 @@ from django.db import models
 from django.test import TestCase
 from django.utils import timezone
 
-from wagtail.models import Collection, Page, PageLogEntry, PageRevision
+from wagtail.models import Collection, Page, PageLogEntry, Revision
 from wagtail.signals import page_published, page_unpublished
 from wagtail.test.testapp.models import EventPage, SecretPage, SimplePage
 from wagtail.test.utils import WagtailTestUtils
@@ -195,7 +195,7 @@ class TestPublishScheduledPagesCommand(WagtailTestUtils, TestCase):
         p = Page.objects.get(slug="hello-world")
         self.assertFalse(p.live)
         self.assertTrue(
-            PageRevision.objects.filter(page=p)
+            Revision.page_revisions.filter(object_id=p.id)
             .exclude(approved_go_live_at__isnull=True)
             .exists()
         )
@@ -207,7 +207,7 @@ class TestPublishScheduledPagesCommand(WagtailTestUtils, TestCase):
         self.assertTrue(p.first_published_at)
         self.assertFalse(p.has_unpublished_changes)
         self.assertFalse(
-            PageRevision.objects.filter(page=p)
+            Revision.page_revisions.filter(object_id=p.id)
             .exclude(approved_go_live_at__isnull=True)
             .exists()
         )
@@ -248,7 +248,7 @@ class TestPublishScheduledPagesCommand(WagtailTestUtils, TestCase):
         p = Page.objects.get(slug="hello-world")
         self.assertFalse(p.live)
         self.assertTrue(
-            PageRevision.objects.filter(page_id=p.id)
+            Revision.page_revisions.filter(object_id=p.id)
             .exclude(approved_go_live_at__isnull=True)
             .exists()
         )
@@ -260,7 +260,7 @@ class TestPublishScheduledPagesCommand(WagtailTestUtils, TestCase):
         self.assertTrue(p.first_published_at)
         self.assertFalse(p.has_unpublished_changes)
         self.assertFalse(
-            PageRevision.objects.filter(page_id=p.id)
+            Revision.page_revisions.filter(object_id=p.id)
             .exclude(approved_go_live_at__isnull=True)
             .exists()
         )
@@ -308,7 +308,7 @@ class TestPublishScheduledPagesCommand(WagtailTestUtils, TestCase):
         p = Page.objects.get(slug="hello-world")
         self.assertFalse(p.live)
         self.assertTrue(
-            PageRevision.objects.filter(page=p)
+            Revision.page_revisions.filter(object_id=p.id)
             .exclude(approved_go_live_at__isnull=True)
             .exists()
         )
@@ -318,7 +318,7 @@ class TestPublishScheduledPagesCommand(WagtailTestUtils, TestCase):
         p = Page.objects.get(slug="hello-world")
         self.assertFalse(p.live)
         self.assertTrue(
-            PageRevision.objects.filter(page=p)
+            Revision.page_revisions.filter(object_id=p.id)
             .exclude(approved_go_live_at__isnull=True)
             .exists()
         )
@@ -393,14 +393,18 @@ class TestPublishScheduledPagesCommand(WagtailTestUtils, TestCase):
         p = Page.objects.get(slug="hello-world")
         self.assertFalse(p.live)
         self.assertTrue(
-            PageRevision.objects.filter(page=p, submitted_for_moderation=True).exists()
+            Revision.page_revisions.filter(
+                object_id=p.id, submitted_for_moderation=True
+            ).exists()
         )
 
         management.call_command("publish_scheduled_pages")
 
         p = Page.objects.get(slug="hello-world")
         self.assertFalse(
-            PageRevision.objects.filter(page=p, submitted_for_moderation=True).exists()
+            Revision.page_revisions.filter(
+                object_id=p.id, submitted_for_moderation=True
+            ).exists()
         )
 
 
@@ -436,8 +440,12 @@ class TestPurgeRevisionsCommand(TestCase):
         self.run_command()
 
         # revision 1 should be deleted, revision 2 should not be
-        self.assertNotIn(revision_1, PageRevision.objects.filter(page=self.page))
-        self.assertIn(revision_2, PageRevision.objects.filter(page=self.page))
+        self.assertNotIn(
+            revision_1, Revision.page_revisions.filter(object_id=self.page.id)
+        )
+        self.assertIn(
+            revision_2, Revision.page_revisions.filter(object_id=self.page.id)
+        )
 
     def test_revisions_in_moderation_not_purged(self):
 
@@ -448,8 +456,8 @@ class TestPurgeRevisionsCommand(TestCase):
         self.run_command()
 
         self.assertTrue(
-            PageRevision.objects.filter(
-                page=self.page, submitted_for_moderation=True
+            Revision.page_revisions.filter(
+                object_id=self.page.id, submitted_for_moderation=True
             ).exists()
         )
 
@@ -465,7 +473,9 @@ class TestPurgeRevisionsCommand(TestCase):
             self.run_command()
             # even though no longer the latest revision, the old revision should stay as it is
             # attached to an in progress workflow
-            self.assertIn(revision, PageRevision.objects.filter(page=self.page))
+            self.assertIn(
+                revision, Revision.page_revisions.filter(object_id=self.page.id)
+            )
         except ImportError:
             pass
 
@@ -479,7 +489,9 @@ class TestPurgeRevisionsCommand(TestCase):
 
         self.run_command()
 
-        self.assertIn(approved_revision, PageRevision.objects.filter(page=self.page))
+        self.assertIn(
+            approved_revision, Revision.page_revisions.filter(object_id=self.page.id)
+        )
 
     def test_purge_revisions_with_date_cutoff(self):
 
@@ -490,7 +502,9 @@ class TestPurgeRevisionsCommand(TestCase):
         self.run_command(days=30)
 
         # revision should not be deleted, as it is younger than 30 days
-        self.assertIn(old_revision, PageRevision.objects.filter(page=self.page))
+        self.assertIn(
+            old_revision, Revision.page_revisions.filter(object_id=self.page.id)
+        )
 
         old_revision.created_at = timezone.now() - timedelta(days=31)
         old_revision.save()
@@ -498,7 +512,9 @@ class TestPurgeRevisionsCommand(TestCase):
         self.run_command(days=30)
 
         # revision is now older than 30 days, so should be deleted
-        self.assertNotIn(old_revision, PageRevision.objects.filter(page=self.page))
+        self.assertNotIn(
+            old_revision, Revision.page_revisions.filter(object_id=self.page.id)
+        )
 
 
 class TestCreateLogEntriesFromRevisionsCommand(TestCase):
@@ -566,8 +582,9 @@ class TestCreateLogEntriesFromRevisionsCommand(TestCase):
 
     def test_command_doesnt_crash_for_revisions_without_page_model(self):
         with mock.patch(
-            "wagtail.models.ContentType.model_class",
+            "wagtail.models.Page.specific_class",
             return_value=None,
+            new_callable=mock.PropertyMock,
         ):
             management.call_command("create_log_entries_from_revisions")
             self.assertEqual(PageLogEntry.objects.count(), 0)
