@@ -45,10 +45,7 @@ class UsernameForm(forms.ModelForm):
         if User.USERNAME_FIELD == "username":
             field = self.fields["username"]
             field.regex = r"^[\w.@+-]+$"
-            field.help_text = _(
-                "Required. 30 characters or fewer. Letters, "
-                "digits and @/./+/-/_ only."
-            )
+            field.help_text = _("Required. Letters, digits and @/./+/-/_ only.")
             field.error_messages = field.error_messages.copy()
             field.error_messages.update(
                 {
@@ -263,7 +260,7 @@ class GroupForm(forms.ModelForm):
             return name
         raise forms.ValidationError(self.error_messages["duplicate_name"])
 
-    def save(self):
+    def save(self, commit=True):
         # We go back to the object to read (in order to reapply) the
         # permissions which were set on this group, but which are not
         # accessible in the wagtail admin interface, as otherwise these would
@@ -278,7 +275,7 @@ class GroupForm(forms.ModelForm):
         except ValueError:
             # this form is not bound; we're probably creating a new group
             untouchable_permissions = []
-        group = super().save()
+        group = super().save(commit=commit)
         group.permissions.add(*untouchable_permissions)
         return group
 
